@@ -205,8 +205,8 @@ cb_colrow_index_counter (gpointer data, gpointer user_data)
 		*count += index->last - index->first + 1;
 }
 
-gint             
-colrow_vis_list_length (ColRowVisList *list) 
+gint
+colrow_vis_list_length (ColRowVisList *list)
 {
 	gint count = 0;
 	g_slist_foreach (list, cb_colrow_index_counter, &count);
@@ -337,6 +337,13 @@ colrow_set_single_state (ColRowState *state,
 	state->visible = info->visible;
 }
 
+ColRowStateList *
+colrow_state_list_destroy (ColRowStateList *list)
+{
+	go_slist_free_custom (list, g_free);
+	return NULL;
+}
+
 ColRowStateList *
 colrow_get_states (Sheet *sheet, gboolean is_cols, int first, int last)
 {
@@ -451,7 +458,7 @@ ColRowStateGroup *
 colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 		  ColRowIndexList *src, int new_size, int from, int to)
 /* from & to are used to restrict fitting to that range. Pass 0, -1 if you want to use the */
-/*whole row/column */
+/* whole row/column */
 {
 	int i;
 	ColRowStateGroup *res = NULL;
@@ -519,7 +526,7 @@ colrow_set_sizes (Sheet *sheet, gboolean is_cols,
 		for (i = index->first ; i <= index->last ; ++i) {
 			int tmp = new_size;
 			if (tmp < 0) {
-				int max = is_cols ? gnm_sheet_get_last_row (sheet) 
+				int max = is_cols ? gnm_sheet_get_last_row (sheet)
 					: gnm_sheet_get_last_col (sheet);
 				if (from < 0)
 					from = 0;
@@ -801,6 +808,25 @@ colrow_autofit (Sheet *sheet, const GnmRange *range, gboolean is_cols,
 	colrow_foreach (crs, a, b, handler, &data);
 }
 
+void
+colrow_autofit_col (Sheet *sheet, GnmRange *r)
+{
+	colrow_autofit (sheet, r, TRUE, TRUE,
+			TRUE, FALSE, NULL, NULL);
+	sheet_foreach_cell_in_range (sheet, CELL_ITER_IGNORE_BLANK,
+				     r->start.col, 0,
+				     r->end.col, gnm_sheet_get_last_row (sheet),
+				     (CellIterFunc) &cb_clear_variable_width_content,
+				     NULL);
+}
+
+void
+colrow_autofit_row (Sheet *sheet, GnmRange *r)
+{
+	colrow_autofit (sheet, r, FALSE, FALSE,
+			TRUE, FALSE, NULL, NULL);
+}
+
 /*****************************************************************************/
 
 typedef struct
