@@ -27,6 +27,7 @@
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
+#include <dead-kittens.h>
 
 #include <sheet.h>
 #include <sheet-view.h>
@@ -59,7 +60,6 @@
 #include <goffice/canvas/goc-canvas.h>
 #include <goffice/canvas/goc-item.h>
 #include <goffice/canvas/goc-rectangle.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 
 #include <string.h>
@@ -123,7 +123,7 @@ typedef struct {
 } ExprEntry;
 
 typedef struct _FormatState {
-	GladeXML	*gui;
+	GtkBuilder	*gui;
 	WBCGtk	*wbcg;
 	GtkDialog	*dialog;
 	GtkNotebook	*notebook;
@@ -308,7 +308,7 @@ cb_toggle_changed (GtkToggleButton *button, PatternPicker *picker)
  */
 static void
 setup_pattern_button (GdkScreen *screen,
-		      GladeXML  *gui,
+		      GtkBuilder  *gui,
 		      char const *const name,
 		      PatternPicker *picker,
 		      gboolean const flag,
@@ -316,7 +316,7 @@ setup_pattern_button (GdkScreen *screen,
 		      int const select_index,
 		      unsigned size)
 {
-	GtkWidget *tmp = glade_xml_get_widget (gui, name);
+	GtkWidget *tmp = go_gtk_builder_get_widget (gui, name);
 	if (tmp != NULL) {
 		GtkButton *button = GTK_BUTTON (tmp);
 		if (flag) {
@@ -349,7 +349,7 @@ setup_pattern_button (GdkScreen *screen,
 						      TRUE);
 		}
 	} else
-		g_warning ("CellFormat: Unexpected missing glade widget");
+		g_warning ("CellFormat: Unexpected missing widget");
 }
 
 static void
@@ -412,11 +412,11 @@ setup_color_pickers (FormatState *state,
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
 	gtk_container_add (GTK_CONTAINER (frame), combo);
 
-	w = glade_xml_get_widget (state->gui, container);
+	w = go_gtk_builder_get_widget (state->gui, container);
 	gtk_box_pack_start (GTK_BOX (w), frame, FALSE, FALSE, 0);
 	gtk_widget_show_all (frame);
 
-	w = glade_xml_get_widget (state->gui, label);
+	w = go_gtk_builder_get_widget (state->gui, label);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (w), combo);
 
 	if (def_sc)
@@ -433,9 +433,9 @@ setup_color_pickers (FormatState *state,
  * button of the same name.
  */
 static GtkWidget *
-init_button_image (GladeXML *gui, char const *name)
+init_button_image (GtkBuilder *gui, char const *name)
 {
-	GtkWidget *tmp = glade_xml_get_widget (gui, name);
+	GtkWidget *tmp = go_gtk_builder_get_widget (gui, name);
 	if (tmp != NULL) {
 		GdkScreen *screen = gtk_widget_get_screen (tmp);
 		GdkPixbuf *pixbuf = gtk_icon_theme_load_icon (
@@ -571,7 +571,7 @@ fmt_dialog_init_align_radio (char const *const name,
 			     FormatState *state,
 			     GCallback handler)
 {
-	GtkWidget *tmp = glade_xml_get_widget (state->gui, name);
+	GtkWidget *tmp = go_gtk_builder_get_widget (state->gui, name);
 	if (tmp != NULL) {
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp),
 					      val == target);
@@ -649,7 +649,7 @@ fmt_dialog_init_align_page (FormatState *state)
 	if (0 == (state->conflicts & (1 << MSTYLE_WRAP_TEXT)))
 		wrap = gnm_style_get_wrap_text (state->style);
 
-	w = glade_xml_get_widget (state->gui, "align_wrap");
+	w = go_gtk_builder_get_widget (state->gui, "align_wrap");
 	state->align.wrap = GTK_CHECK_BUTTON (w);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), wrap);
 	g_signal_connect (G_OBJECT (w),
@@ -663,8 +663,8 @@ fmt_dialog_init_align_page (FormatState *state)
 		state->align.indent = gnm_style_get_indent (state->style);
 
 	state->align.indent_label =
-		glade_xml_get_widget (state->gui, "halign_indent_label");
-	w = glade_xml_get_widget (state->gui, "halign_indent");
+		go_gtk_builder_get_widget (state->gui, "halign_indent_label");
+	w = go_gtk_builder_get_widget (state->gui, "halign_indent");
 	state->align.indent_button = GTK_SPIN_BUTTON (w);
 	gtk_spin_button_set_value (state->align.indent_button, state->align.indent);
 	gtk_widget_set_sensitive (GTK_WIDGET (state->align.indent_button),
@@ -689,8 +689,9 @@ fmt_dialog_init_align_page (FormatState *state)
 			r -= 360;
 	} else
 		r = 0;
-	state->align.rotation = (GORotationSel *)
-		glade_xml_get_widget (state->gui, "rotation_selector");
+	state->align.rotation = (GORotationSel *) go_rotation_sel_new ();
+	gtk_box_pack_start (GTK_BOX (go_gtk_builder_get_widget (state->gui, "alignment_box")),
+	                    GTK_WIDGET (state->align.rotation), TRUE, TRUE, 0);
 	go_rotation_sel_set_rotation (state->align.rotation, r);
 	g_signal_connect (G_OBJECT (state->align.rotation), "rotation-changed",
 		G_CALLBACK (cb_rotation_changed), state);
@@ -811,10 +812,10 @@ fmt_dialog_init_font_page (FormatState *state)
 {
 	GtkWidget *tmp = font_selector_new ();
 	FontSelector *font_widget = FONT_SELECTOR (tmp);
-	GtkWidget *container = glade_xml_get_widget (state->gui, "font_box");
-	GtkWidget *uline = glade_xml_get_widget (state->gui, "underline_combo");
+	GtkWidget *container = go_gtk_builder_get_widget (state->gui, "font_box");
+	GtkWidget *uline = go_combo_text_new_default ();
 	char const *uline_str;
-	GtkWidget *strike = glade_xml_get_widget (state->gui, "strikethrough_button");
+	GtkWidget *strike = go_gtk_builder_get_widget (state->gui, "strikethrough_button");
 	gboolean   strikethrough = FALSE;
 	GOFontScript script = GO_FONT_SCRIPT_STANDARD;
 	int i;
@@ -861,8 +862,10 @@ fmt_dialog_init_font_page (FormatState *state)
 		"entry_changed",
 		G_CALLBACK (cb_font_underline_changed), state);
 	gtk_widget_show_all (uline);
+	gtk_box_pack_start (GTK_BOX (go_gtk_builder_get_widget (state->gui, "underline-box")),
+	                    uline, TRUE, TRUE, 0);
 
-	tmp = glade_xml_get_widget (state->gui, "underline_label");
+	tmp = go_gtk_builder_get_widget (state->gui, "underline_label");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (tmp), uline);
 
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_STRIKETHROUGH)))
@@ -876,14 +879,14 @@ fmt_dialog_init_font_page (FormatState *state)
 	if (0 == (state->conflicts & (1 << MSTYLE_FONT_SCRIPT)))
 		script = gnm_style_get_font_script (state->style);
 	font_selector_set_script (state->font.selector, script);
-	if (NULL != (tmp = glade_xml_get_widget (state->gui, "superscript_button"))) {
+	if (NULL != (tmp = go_gtk_builder_get_widget (state->gui, "superscript_button"))) {
 		state->font.superscript = GTK_TOGGLE_BUTTON (tmp);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp),
 			script == GO_FONT_SCRIPT_SUPER);
 		g_signal_connect (G_OBJECT (tmp), "toggled",
 			G_CALLBACK (cb_font_script_toggle), state);
 	}
-	if (NULL != (tmp =  glade_xml_get_widget (state->gui, "subscript_button"))) {
+	if (NULL != (tmp =  go_gtk_builder_get_widget (state->gui, "subscript_button"))) {
 		state->font.subscript = GTK_TOGGLE_BUTTON (tmp);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp),
 			script == GO_FONT_SCRIPT_SUB);
@@ -978,7 +981,7 @@ fmt_dialog_init_background_page (FormatState *state)
 	state->back.canvas = GOC_CANVAS (widget);
 	gtk_widget_set_size_request (widget, w, h);
 
-	widget = glade_xml_get_widget (state->gui, "back_sample_frame");
+	widget = go_gtk_builder_get_widget (state->gui, "back_sample_frame");
 	gtk_container_add (GTK_CONTAINER (widget),
 		GTK_WIDGET (state->back.canvas));
 	gtk_widget_show_all (widget);
@@ -1263,7 +1266,7 @@ draw_border_preview (FormatState *state)
 		gtk_widget_show (GTK_WIDGET (state->border.canvas));
 		gtk_widget_set_size_request (GTK_WIDGET (state->border.canvas),
 					     150, 100);
-		gtk_container_add (GTK_CONTAINER (glade_xml_get_widget (state->gui, "border_sample_container")),
+		gtk_container_add (GTK_CONTAINER (go_gtk_builder_get_widget (state->gui, "border_sample_container")),
 				   GTK_WIDGET (state->border.canvas));
 		group = GOC_GROUP (goc_canvas_get_root (state->border.canvas));
 
@@ -1515,7 +1518,7 @@ fmt_dialog_init_protection_page (FormatState *state)
 
 	flag = (state->conflicts & (1 << MSTYLE_CONTENTS_LOCKED))
 		? FALSE : gnm_style_get_contents_locked (state->style);
-	w = glade_xml_get_widget (state->gui, "protection_locked");
+	w = go_gtk_builder_get_widget (state->gui, "protection_locked");
 	state->protection.locked = GTK_CHECK_BUTTON (w);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), flag);
 	g_signal_connect (G_OBJECT (w),
@@ -1524,7 +1527,7 @@ fmt_dialog_init_protection_page (FormatState *state)
 
 	flag = (state->conflicts & (1 << MSTYLE_CONTENTS_HIDDEN))
 		? FALSE : gnm_style_get_contents_hidden (state->style);
-	w = glade_xml_get_widget (state->gui, "protection_hidden");
+	w = go_gtk_builder_get_widget (state->gui, "protection_hidden");
 	state->protection.hidden = GTK_CHECK_BUTTON (w);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), flag);
 	g_signal_connect (G_OBJECT (w),
@@ -1533,7 +1536,7 @@ fmt_dialog_init_protection_page (FormatState *state)
 
 	state->protection.sheet_protected_changed = FALSE;
 	flag = state->sheet->is_protected;
-	w = glade_xml_get_widget (state->gui, "protection_sheet_protected");
+	w = go_gtk_builder_get_widget (state->gui, "protection_sheet_protected");
 	state->protection.sheet_protected = GTK_CHECK_BUTTON (w);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), flag);
 	g_signal_connect (G_OBJECT (w),
@@ -1733,7 +1736,7 @@ static void
 fmt_dialog_init_validation_expr_entry (FormatState *state, ExprEntry *entry,
 				       char const *name, int i)
 {
-	entry->name  = GTK_LABEL (glade_xml_get_widget (state->gui, name));
+	entry->name  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, name));
 	entry->entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gtk_table_attach (state->validation.criteria_table,
 		GTK_WIDGET (entry->entry),
@@ -1822,23 +1825,23 @@ fmt_dialog_init_validation_page (FormatState *state)
 	/* Setup widgets */
 	state->validation.changed	  = FALSE;
 	state->validation.valid		  = 1;
-	state->validation.criteria_table  = GTK_TABLE          (glade_xml_get_widget (state->gui, "validation_criteria_table"));
-	state->validation.constraint_type = GTK_COMBO_BOX    (glade_xml_get_widget (state->gui, "validation_constraint_type"));
+	state->validation.criteria_table  = GTK_TABLE          (go_gtk_builder_get_widget (state->gui, "validation_criteria_table"));
+	state->validation.constraint_type = GTK_COMBO_BOX    (go_gtk_builder_get_widget (state->gui, "validation_constraint_type"));
 	gtk_combo_box_set_active (state->validation.constraint_type, 0);
-	state->validation.operator_label  = GTK_LABEL          (glade_xml_get_widget (state->gui, "validation_operator_label"));
-	state->validation.op		     = GTK_COMBO_BOX    (glade_xml_get_widget (state->gui, "validation_operator"));
+	state->validation.operator_label  = GTK_LABEL          (go_gtk_builder_get_widget (state->gui, "validation_operator_label"));
+	state->validation.op		     = GTK_COMBO_BOX    (go_gtk_builder_get_widget (state->gui, "validation_operator"));
 	gtk_combo_box_set_active (state->validation.op, 0);
-	state->validation.allow_blank	     = GTK_TOGGLE_BUTTON(glade_xml_get_widget (state->gui, "validation_ignore_blank"));
-	state->validation.use_dropdown       = GTK_TOGGLE_BUTTON(glade_xml_get_widget (state->gui, "validation_in_dropdown"));
-	state->validation.error.action_label = GTK_LABEL       (glade_xml_get_widget (state->gui, "validation_error_action_label"));
-	state->validation.error.title_label  = GTK_LABEL       (glade_xml_get_widget (state->gui, "validation_error_title_label"));
-	state->validation.error.msg_label    = GTK_LABEL       (glade_xml_get_widget (state->gui, "validation_error_msg_label"));
-	state->validation.error.action       = GTK_COMBO_BOX (glade_xml_get_widget (state->gui, "validation_error_action"));
+	state->validation.allow_blank	     = GTK_TOGGLE_BUTTON(go_gtk_builder_get_widget (state->gui, "validation_ignore_blank"));
+	state->validation.use_dropdown       = GTK_TOGGLE_BUTTON(go_gtk_builder_get_widget (state->gui, "validation_in_dropdown"));
+	state->validation.error.action_label = GTK_LABEL       (go_gtk_builder_get_widget (state->gui, "validation_error_action_label"));
+	state->validation.error.title_label  = GTK_LABEL       (go_gtk_builder_get_widget (state->gui, "validation_error_title_label"));
+	state->validation.error.msg_label    = GTK_LABEL       (go_gtk_builder_get_widget (state->gui, "validation_error_msg_label"));
+	state->validation.error.action       = GTK_COMBO_BOX (go_gtk_builder_get_widget (state->gui, "validation_error_action"));
 	build_validation_error_combo (state->validation.error.action);
 	gtk_combo_box_set_active (state->validation.error.action, 0);
-	state->validation.error.title        = GTK_ENTRY       (glade_xml_get_widget (state->gui, "validation_error_title"));
-	state->validation.error.msg          = GTK_TEXT_VIEW   (glade_xml_get_widget (state->gui, "validation_error_msg"));
-	state->validation.error.image        = GTK_IMAGE       (glade_xml_get_widget (state->gui, "validation_error_image"));
+	state->validation.error.title        = GTK_ENTRY       (go_gtk_builder_get_widget (state->gui, "validation_error_title"));
+	state->validation.error.msg          = GTK_TEXT_VIEW   (go_gtk_builder_get_widget (state->gui, "validation_error_msg"));
+	state->validation.error.image        = GTK_IMAGE       (go_gtk_builder_get_widget (state->gui, "validation_error_image"));
 
 	gnumeric_editable_enters (
 		GTK_WINDOW (state->dialog),
@@ -1929,11 +1932,11 @@ fmt_dialog_init_input_msg_page (FormatState *state)
 #endif
 
 	/* Setup widgets */
-	state->input_msg.flag        = GTK_TOGGLE_BUTTON (glade_xml_get_widget (state->gui, "input_msg_flag"));
-	state->input_msg.title_label = GTK_LABEL         (glade_xml_get_widget (state->gui, "input_msg_title_label"));
-	state->input_msg.msg_label   = GTK_LABEL         (glade_xml_get_widget (state->gui, "input_msg_msg_label"));
-	state->input_msg.title       = GTK_ENTRY         (glade_xml_get_widget (state->gui, "input_msg_title"));
-	state->input_msg.msg         = GTK_TEXT_VIEW     (glade_xml_get_widget (state->gui, "input_msg_msg"));
+	state->input_msg.flag        = GTK_TOGGLE_BUTTON (go_gtk_builder_get_widget (state->gui, "input_msg_flag"));
+	state->input_msg.title_label = GTK_LABEL         (go_gtk_builder_get_widget (state->gui, "input_msg_title_label"));
+	state->input_msg.msg_label   = GTK_LABEL         (go_gtk_builder_get_widget (state->gui, "input_msg_msg_label"));
+	state->input_msg.title       = GTK_ENTRY         (go_gtk_builder_get_widget (state->gui, "input_msg_title"));
+	state->input_msg.msg         = GTK_TEXT_VIEW     (go_gtk_builder_get_widget (state->gui, "input_msg_msg"));
 
 	gnumeric_editable_enters (
 		GTK_WINDOW (state->dialog),
@@ -2187,26 +2190,26 @@ fmt_dialog_init_conditions_page (FormatState *state)
 
 	g_return_if_fail (state != NULL);
 
-	state->conditions.add = GTK_BUTTON (glade_xml_get_widget (state->gui,
+	state->conditions.add = GTK_BUTTON (go_gtk_builder_get_widget (state->gui,
 								     "conditions_add"));
 	gtk_widget_set_sensitive (GTK_WIDGET (state->conditions.add), FALSE);
-	state->conditions.remove = GTK_BUTTON (glade_xml_get_widget (state->gui,
+	state->conditions.remove = GTK_BUTTON (go_gtk_builder_get_widget (state->gui,
 								     "conditions_remove"));
 	gtk_widget_set_sensitive (GTK_WIDGET (state->conditions.remove), FALSE);
-	state->conditions.clear = GTK_BUTTON (glade_xml_get_widget (state->gui,
+	state->conditions.clear = GTK_BUTTON (go_gtk_builder_get_widget (state->gui,
 								     "conditions_clear"));
 	gtk_widget_set_sensitive (GTK_WIDGET (state->conditions.clear), FALSE);
-	state->conditions.expand = GTK_BUTTON (glade_xml_get_widget (state->gui,
+	state->conditions.expand = GTK_BUTTON (go_gtk_builder_get_widget (state->gui,
 								     "conditions_expand"));
 	gtk_widget_set_sensitive (GTK_WIDGET (state->conditions.expand), FALSE);
-	state->conditions.edit = GTK_BUTTON (glade_xml_get_widget (state->gui,
+	state->conditions.edit = GTK_BUTTON (go_gtk_builder_get_widget (state->gui,
 								     "conditions_edit"));
 	gtk_widget_set_sensitive (GTK_WIDGET (state->conditions.edit), FALSE);
 
 	state->conditions.model = gtk_tree_store_new (CONDITIONS_NUM_COLUMNS,
 						      G_TYPE_STRING,
 						      G_TYPE_STRING);
-	treeview = GTK_TREE_VIEW (glade_xml_get_widget (state->gui, "conditions_treeview"));
+	treeview = GTK_TREE_VIEW (go_gtk_builder_get_widget (state->gui, "conditions_treeview"));
 	gtk_tree_view_set_fixed_height_mode (treeview, FALSE);
 	gtk_tree_view_set_model (treeview, GTK_TREE_MODEL (state->conditions.model));
 	renderer = gtk_cell_renderer_text_new ();
@@ -2219,7 +2222,7 @@ fmt_dialog_init_conditions_page (FormatState *state)
 	gtk_tree_view_insert_column (treeview, column, -1);
 	gtk_tree_view_set_expander_column (treeview, column);
 
-	state->conditions.label = GTK_LABEL (glade_xml_get_widget (state->gui,
+	state->conditions.label = GTK_LABEL (go_gtk_builder_get_widget (state->gui,
 								   "conditions_label"));
 	if (state->conflicts & (1 << MSTYLE_CONDITIONS)) {
 		gtk_label_set_markup (state->conditions.label,
@@ -2274,7 +2277,7 @@ cb_fmt_dialog_dialog_buttons (GtkWidget *btn, FormatState *state)
 		/* since we are acting on the current selection   */
 		/* validation may have switched sheets.           */
 
-		wb_control_sheet_focus (WORKBOOK_CONTROL (state->wbcg), 
+		wb_control_sheet_focus (WORKBOOK_CONTROL (state->wbcg),
 					state->sheet);
 
 		if (state->validation.changed)
@@ -2347,6 +2350,13 @@ cb_fmt_dialog_set_focus (G_GNUC_UNUSED GtkWidget *window,
 		validation_rebuild_validation (state);
 }
 
+static void
+cb_dialog_destroy (GtkDialog *dialog)
+{
+	g_object_set_data (G_OBJECT (dialog), "state", NULL);
+}
+
+
 /* Set initial focus */
 static void
 set_initial_focus (FormatState *s)
@@ -2361,30 +2371,22 @@ set_initial_focus (FormatState *s)
 		go_format_sel_set_focus (GO_FORMAT_SEL (s->format_sel));
 		return;
 	} else if (strcmp (name, "alignment_box") == 0)
-	      focus_widget = glade_xml_get_widget (s->gui, "halign_left");
+	      focus_widget = go_gtk_builder_get_widget (s->gui, "halign_left");
 	else if (strcmp (name, "font_box") == 0)
 	      focus_widget = GTK_WIDGET (s->font.selector);
 	else if (strcmp (name, "border_box") == 0)
-	      focus_widget = glade_xml_get_widget (s->gui, "outline_border");
+	      focus_widget = go_gtk_builder_get_widget (s->gui, "outline_border");
 	else if (strcmp (name, "background_box") == 0)
-	      focus_widget = glade_xml_get_widget (s->gui, "back_color_auto");
+	      focus_widget = go_gtk_builder_get_widget (s->gui, "back_color_auto");
 	else if (strcmp (name, "protection_box") == 0)
 	      focus_widget = GTK_WIDGET (s->protection.locked);
 	else
 		focus_widget = NULL;
 
-
-#ifdef HAVE_GTK_WIDGET_GET_CAN_FOCUS
-	if (focus_widget
-	    && gtk_widget_get_can_focus (focus_widget)
-	    && gtk_widget_is_sensitive (focus_widget))
+	if (focus_widget &&
+	    gtk_widget_get_can_focus (focus_widget) &&
+	    gtk_widget_is_sensitive (focus_widget))
 		gtk_widget_grab_focus (focus_widget);
-#else
-	if (focus_widget
-	    && GTK_WIDGET_CAN_FOCUS (focus_widget)
-	    && GTK_WIDGET_IS_SENSITIVE (focus_widget))
-		gtk_widget_grab_focus (focus_widget);
-#endif
 }
 
 static void
@@ -2467,14 +2469,14 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	GOColor default_border_color;
 	int default_border_style = GNM_STYLE_BORDER_THIN;
 
-	GtkWidget *tmp, *dialog = glade_xml_get_widget (state->gui, "CellFormat");
+	GtkWidget *tmp, *dialog = go_gtk_builder_get_widget (state->gui, "CellFormat");
 	g_return_if_fail (dialog != NULL);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Format Cells"));
 
 	/* Initialize */
 	state->dialog	   = GTK_DIALOG (dialog);
-	state->notebook	   = GTK_NOTEBOOK (glade_xml_get_widget (state->gui, "notebook"));
+	state->notebook	   = GTK_NOTEBOOK (go_gtk_builder_get_widget (state->gui, "notebook"));
 
 	state->enable_edit = FALSE;  /* Enable below */
 
@@ -2495,7 +2497,7 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	fmt_dialog_init_input_msg_page (state);
 	fmt_dialog_init_conditions_page (state);
 
-	default_border_color = GO_COLOR_FROM_GDK (GTK_WIDGET (state->dialog)->style->black);
+	default_border_color = GO_COLOR_FROM_GDK (gtk_widget_get_style (GTK_WIDGET (state->dialog))->black);
 
 	if (pageno == FD_CURRENT)
 		pageno = fmt_dialog_page;
@@ -2605,19 +2607,19 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	draw_border_preview (state);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "helpbutton"),
+		go_gtk_builder_get_widget (state->gui, "helpbutton"),
 		GNUMERIC_HELP_LINK_CELL_FORMAT);
 
-	state->ok_button = glade_xml_get_widget (state->gui, "okbutton");
+	state->ok_button = go_gtk_builder_get_widget (state->gui, "okbutton");
 	g_signal_connect (G_OBJECT (state->ok_button),
 		"clicked",
 		G_CALLBACK (cb_fmt_dialog_dialog_buttons), state);
-	state->apply_button = glade_xml_get_widget (state->gui, "applybutton");
+	state->apply_button = go_gtk_builder_get_widget (state->gui, "applybutton");
 	gtk_widget_set_sensitive (state->apply_button, FALSE);
 	g_signal_connect (G_OBJECT (state->apply_button),
 		"clicked",
 		G_CALLBACK (cb_fmt_dialog_dialog_buttons), state);
-	tmp = glade_xml_get_widget (state->gui, "cancelbutton");
+	tmp = go_gtk_builder_get_widget (state->gui, "cancelbutton");
 	g_signal_connect (G_OBJECT (tmp),
 		"clicked",
 		G_CALLBACK (cb_fmt_dialog_dialog_buttons), state);
@@ -2650,6 +2652,8 @@ fmt_dialog_impl (FormatState *state, FormatDialogPosition_t pageno)
 	wbc_gtk_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify)cb_fmt_dialog_dialog_destroy);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+			  G_CALLBACK (cb_dialog_destroy), NULL);
 
 	gnumeric_restore_window_geometry (GTK_WINDOW (state->dialog),
 					  CELL_FORMAT_KEY);
@@ -2730,14 +2734,13 @@ fmt_dialog_selection_type (SheetView *sv,
 void
 dialog_cell_format (WBCGtk *wbcg, FormatDialogPosition_t pageno)
 {
-	GladeXML     *gui;
+	GtkBuilder     *gui;
 	GnmCell	     *edit_cell;
 	FormatState  *state;
 
 	g_return_if_fail (wbcg != NULL);
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"cell-format.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("cell-format.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
