@@ -40,7 +40,6 @@
 
 #include <goffice/goffice.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 
 #include <glib-object.h>
@@ -59,7 +58,7 @@ enum {
 };
 
 typedef struct {
-	GladeXML		*gui;
+	GtkBuilder		*gui;
 	GtkWidget		*dialog;
 
 	/*pointer to the document metadata*/
@@ -562,7 +561,6 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 	GsfDocProp *doc_prop;
 	GValue     *existing_value = NULL;
 	char const *existing_link  = NULL;
-	GValue     *doc_prop_value;
 	GType       val_type;
 
 	existing_prop = gsf_doc_meta_data_lookup (state->metadata, name);
@@ -608,12 +606,14 @@ dialog_doc_metadata_set_gsf_prop (DialogDocMetaData *state,
 	/* Create a new GsfDocProp */
 	doc_prop = gsf_doc_prop_new (g_strdup (name));
 
-	/* Create a new Value */
-	doc_prop_value = g_new0 (GValue, 1);
-
 	val_type = dialog_doc_metadata_get_gsf_prop_val_type (state, name);
 
 	if (val_type != G_TYPE_INVALID) {
+		GValue     *doc_prop_value;
+		
+		/* Create a new Value */
+		doc_prop_value = g_new0 (GValue, 1);
+
 		g_value_init (doc_prop_value, val_type);
 		dialog_doc_metadata_set_gsf_prop_val (state, doc_prop_value, value);
 		gsf_doc_prop_set_val (doc_prop, doc_prop_value);
@@ -1055,7 +1055,7 @@ cb_dialog_doc_metadata_remove_clicked (GtkWidget         *remove_bt,
 			       &list_iter);
 
 	/* Clear entries on 'Properties' page */
-	entry = GTK_ENTRY (GTK_BIN (state->ppt_name)->child);
+	entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (state->ppt_name)));
 	gtk_entry_set_text (entry, "");
 
 	gtk_entry_set_text (state->ppt_value, "");
@@ -1418,7 +1418,7 @@ dialog_doc_metadata_init_calculations_page (DialogDocMetaData *state)
 {
 	char *buf;
 
-	gtk_toggle_button_set_active 
+	gtk_toggle_button_set_active
 		(GTK_TOGGLE_BUTTON ( workbook_get_recalcmode (state->wb) ? state->recalc_auto : state->recalc_manual),
 		 TRUE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (state->recalc_iteration),
@@ -1497,64 +1497,64 @@ dialog_doc_metadata_free (DialogDocMetaData *state)
 static void
 dialog_doc_metadata_init_widgets (DialogDocMetaData *state)
 {
-	state->dialog = glade_xml_get_widget (state->gui, "GOMetadataDialog");
+	state->dialog = go_gtk_builder_get_widget (state->gui, "GOMetadataDialog");
 
-	state->notebook     = GTK_NOTEBOOK (glade_xml_get_widget (state->gui, "notebook"));
-	state->help_button  = GTK_BUTTON (glade_xml_get_widget (state->gui, "help_button"));
-	state->close_button = GTK_BUTTON (glade_xml_get_widget (state->gui, "close_button"));
+	state->notebook     = GTK_NOTEBOOK (go_gtk_builder_get_widget (state->gui, "notebook"));
+	state->help_button  = GTK_BUTTON (go_gtk_builder_get_widget (state->gui, "help_button"));
+	state->close_button = GTK_BUTTON (go_gtk_builder_get_widget (state->gui, "close_button"));
 
 	/* File Information Page */
-	state->file_name = GTK_LABEL (glade_xml_get_widget (state->gui, "file_name"));
-	state->location  = GTK_LABEL (glade_xml_get_widget (state->gui, "location"));
-	state->created   = GTK_LABEL (glade_xml_get_widget (state->gui, "created"));
-	state->modified  = GTK_LABEL (glade_xml_get_widget (state->gui, "modified"));
-	state->accessed  = GTK_LABEL (glade_xml_get_widget (state->gui, "accessed"));
-	state->owner     = GTK_LABEL (glade_xml_get_widget (state->gui, "owner"));
-	state->group     = GTK_LABEL (glade_xml_get_widget (state->gui, "group"));
+	state->file_name = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "file_name"));
+	state->location  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "location"));
+	state->created   = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "created"));
+	state->modified  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "modified"));
+	state->accessed  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "accessed"));
+	state->owner     = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "owner"));
+	state->group     = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "group"));
 
-	state->owner_read  = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "owner_read"));
-	state->owner_write = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "owner_write"));
+	state->owner_read  = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "owner_read"));
+	state->owner_write = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "owner_write"));
 
-	state->group_read  = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "group_read"));
-	state->group_write = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "group_write"));
+	state->group_read  = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "group_read"));
+	state->group_write = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "group_write"));
 
-	state->others_read  = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "others_read"));
-	state->others_write = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "others_write"));
+	state->others_read  = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "others_read"));
+	state->others_write = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "others_write"));
 
 	/* Description Page */
-	state->title    = GTK_ENTRY (glade_xml_get_widget (state->gui, "title"));
-	state->subject  = GTK_ENTRY (glade_xml_get_widget (state->gui, "subject"));
-	state->author   = GTK_ENTRY (glade_xml_get_widget (state->gui, "author"));
-	state->manager  = GTK_ENTRY (glade_xml_get_widget (state->gui, "manager"));
-	state->company  = GTK_ENTRY (glade_xml_get_widget (state->gui, "company"));
-	state->category = GTK_ENTRY (glade_xml_get_widget (state->gui, "category"));
-	state->keywords = GTK_ENTRY (glade_xml_get_widget (state->gui, "keywords"));
+	state->title    = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "title"));
+	state->subject  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "subject"));
+	state->author   = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "author"));
+	state->manager  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "manager"));
+	state->company  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "company"));
+	state->category = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "category"));
+	state->keywords = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "keywords"));
 
-	state->comments = GTK_TEXT_VIEW (glade_xml_get_widget (state->gui, "comments"));
+	state->comments = GTK_TEXT_VIEW (go_gtk_builder_get_widget (state->gui, "comments"));
 
 	/* Properties Page */
-	state->properties = GTK_TREE_VIEW (glade_xml_get_widget (state->gui, "properties"));
+	state->properties = GTK_TREE_VIEW (go_gtk_builder_get_widget (state->gui, "properties"));
 
-	state->ppt_name  = GTK_COMBO_BOX_ENTRY (glade_xml_get_widget (state->gui, "ppt_name"));
-	state->ppt_value = GTK_ENTRY (glade_xml_get_widget (state->gui, "ppt_value"));
-	state->ppt_link  = GTK_ENTRY (glade_xml_get_widget (state->gui, "ppt_link"));
+	state->ppt_name  = GTK_COMBO_BOX_ENTRY (go_gtk_builder_get_widget (state->gui, "ppt_name"));
+	state->ppt_value = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "ppt_value"));
+	state->ppt_link  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "ppt_link"));
 
-	state->add_button    = GTK_BUTTON (glade_xml_get_widget (state->gui, "add_button"));
-	state->remove_button = GTK_BUTTON (glade_xml_get_widget (state->gui, "remove_button"));
-	state->apply_button  = GTK_BUTTON (glade_xml_get_widget (state->gui, "apply_button"));
+	state->add_button    = GTK_BUTTON (go_gtk_builder_get_widget (state->gui, "add_button"));
+	state->remove_button = GTK_BUTTON (go_gtk_builder_get_widget (state->gui, "remove_button"));
+	state->apply_button  = GTK_BUTTON (go_gtk_builder_get_widget (state->gui, "apply_button"));
 
 	/* Statistics Page */
-	state->sheets = GTK_LABEL (glade_xml_get_widget (state->gui, "sheets"));
-	state->cells  = GTK_LABEL (glade_xml_get_widget (state->gui, "cells"));
-	state->pages  = GTK_LABEL (glade_xml_get_widget (state->gui, "pages"));
+	state->sheets = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "sheets"));
+	state->cells  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "cells"));
+	state->pages  = GTK_LABEL (go_gtk_builder_get_widget (state->gui, "pages"));
 
 	/* Calculations Page */
-	state->recalc_auto = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "recalc_auto"));
-	state->recalc_manual = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "recalc_manual"));
-	state->recalc_iteration = GTK_CHECK_BUTTON (glade_xml_get_widget (state->gui, "iteration_enabled"));
-	state->recalc_max  = GTK_ENTRY (glade_xml_get_widget (state->gui, "max_iterations"));
-	state->recalc_tolerance  = GTK_ENTRY (glade_xml_get_widget (state->gui, "iteration_tolerance"));
-	state->recalc_iteration_table = glade_xml_get_widget (state->gui, "iteration_table");
+	state->recalc_auto = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "recalc_auto"));
+	state->recalc_manual = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "recalc_manual"));
+	state->recalc_iteration = GTK_CHECK_BUTTON (go_gtk_builder_get_widget (state->gui, "iteration_enabled"));
+	state->recalc_max  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "max_iterations"));
+	state->recalc_tolerance  = GTK_ENTRY (go_gtk_builder_get_widget (state->gui, "iteration_tolerance"));
+	state->recalc_iteration_table = go_gtk_builder_get_widget (state->gui, "iteration_table");
 }
 
 static void
@@ -1607,7 +1607,7 @@ typedef struct {
 	GtkTreePath *path;
 } page_search_t;
 
-static gboolean   
+static gboolean
 dialog_doc_metadata_select_page_search (GtkTreeModel *model,
 					GtkTreePath *path,
 					GtkTreeIter *iter,
@@ -1674,17 +1674,15 @@ dialog_doc_metadata_init (DialogDocMetaData *state,
 
 	g_return_val_if_fail (state->metadata  != NULL, TRUE);
 
-	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-					"doc-meta-data.glade",
-					NULL,
-					NULL);
+	state->gui = gnm_gtk_builder_new ("doc-meta-data.ui", NULL,
+	                                  GO_CMD_CONTEXT (wbcg));
 
         if (state->gui == NULL)
                 return TRUE;
 
 	dialog_doc_metadata_init_widgets (state);
 
-	state->view = GTK_TREE_VIEW(glade_xml_get_widget (state->gui, "itemlist"));
+	state->view = GTK_TREE_VIEW(go_gtk_builder_get_widget (state->gui, "itemlist"));
 	state->store = gtk_tree_store_new (NUM_COLUMNS,
 					   GDK_TYPE_PIXBUF,
 					   G_TYPE_STRING,
@@ -1730,7 +1728,7 @@ dialog_doc_metadata_init (DialogDocMetaData *state,
 	for (i = 0; page_info[i].page > -1; i++) {
 		const page_info_t *this_page =  &page_info[i];
 		this_page->page_initializer (state);
-		dialog_doc_meta_data_add_item (state, this_page->page_name, this_page->icon_name, 
+		dialog_doc_meta_data_add_item (state, this_page->page_name, this_page->icon_name,
 					       this_page->page, this_page->parent_path);
 	}
 
