@@ -28,6 +28,7 @@
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
+#include <dead-kittens.h>
 
 #include <parse-util.h>
 #include <gui-util.h>
@@ -61,7 +62,7 @@ typedef struct
 	WBCGtk  *wbcg;
 	Workbook  *wb;
 
-	GladeXML  *gui;
+	GtkBuilder *gui;
 	GtkWidget *dialog;
 	GtkWidget *ok_button;
 	GtkWidget *selector_button;
@@ -185,17 +186,17 @@ dialog_formula_guru_update_this_parent (GtkTreeIter *parent, FormulaGuruState *s
 				gtk_tree_path_free (b);
 			}
 			if (argument && strlen (argument) > 0) {
-				GnmExprTop const *texpr = gnm_expr_parse_str 
-					(argument, state->pos, 
+				GnmExprTop const *texpr = gnm_expr_parse_str
+					(argument, state->pos,
 					 GNM_EXPR_PARSE_DEFAULT,
-					 sheet_get_conventions (state->pos->sheet), 
+					 sheet_get_conventions (state->pos->sheet),
 					 NULL);
 				if (texpr == NULL) {
 					text = g_string_append_c (text, '"');
 					text = g_string_append (text, argument);
 					text = g_string_append_c (text, '"');
 				} else {
-					if ((GNM_EXPR_GET_OPER (texpr->expr) == GNM_EXPR_OP_NAME) 
+					if ((GNM_EXPR_GET_OPER (texpr->expr) == GNM_EXPR_OP_NAME)
 					    && expr_name_is_placeholder (texpr->expr->name.name)
 					    && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (state->quote_button))) {
 						text = g_string_append_c (text, '"');
@@ -328,7 +329,7 @@ dialog_formula_guru_adjust_children (GtkTreeIter *parent, GnmFunc const *fd,
 			g_free (arg_name);
 			arg_name = mod_name;
 		}
-		desc = gnm_func_convert_markup_to_pango 
+		desc = gnm_func_convert_markup_to_pango
 			(gnm_func_get_arg_description (fd, i));
 		gtk_tree_store_set (state->model, &iter,
 				    ARG_NAME, arg_name,
@@ -819,7 +820,7 @@ cb_dialog_formula_guru_query_tooltip (GtkWidget  *widget,
 	GtkTreeIter iter;
 	GtkTreePath *path;
 
-	if (gtk_tree_view_get_tooltip_context 
+	if (gtk_tree_view_get_tooltip_context
 	    (state->treeview, &x_, &y_, keyboard_mode, NULL, &path, &iter)) {
 		char *markup;
 		GtkRcStyle *rc_style = gnumeric_create_tooltip_rc_style ();
@@ -840,20 +841,20 @@ cb_dialog_formula_guru_query_tooltip (GtkWidget  *widget,
 			gtk_widget_show_all (state->tooltip_widget);
 			g_object_ref (G_OBJECT (state->tooltip_widget));
 			g_object_ref (G_OBJECT (state->tooltip_label));
-		} 
+		}
 		gtk_tooltip_set_custom (tooltip, state->tooltip_widget);
 		window = gtk_widget_get_toplevel (state->tooltip_widget);
 		gtk_widget_modify_style /* Applying to window */
 			(window, rc_style);
 		gtk_widget_set_name (window, "gnumeric-tooltip");
 		gtk_widget_set_app_paintable (window, FALSE);
- 
+
 		parent = gtk_widget_get_parent (state->tooltip_widget);
 		if (parent != NULL && GTK_IS_BOX (parent)) {
 			gtk_box_set_spacing (GTK_BOX (parent),0);
 			parent = gtk_widget_get_parent (parent);
 			if (parent != NULL && GTK_IS_ALIGNMENT (parent))
-				gtk_alignment_set_padding 
+				gtk_alignment_set_padding
 					(GTK_ALIGNMENT (parent),
 					 0,0,0,0);
 		}
@@ -881,10 +882,10 @@ dialog_formula_guru_init (FormulaGuruState *state)
 	state->tooltip_widget = NULL;
 
 	/* Set-up treeview */
-	scrolled = glade_xml_get_widget (state->gui, "scrolled");
+	scrolled = go_gtk_builder_get_widget (state->gui, "scrolled");
 	state->model = gtk_tree_store_new (NUM_COLMNS, G_TYPE_STRING, G_TYPE_BOOLEAN,
 					   G_TYPE_STRING, G_TYPE_STRING,
-					   G_TYPE_INT, G_TYPE_INT, G_TYPE_POINTER, 
+					   G_TYPE_INT, G_TYPE_INT, G_TYPE_POINTER,
 					   G_TYPE_STRING);
 	state->treeview = GTK_TREE_VIEW (
 		gtk_tree_view_new_with_model (GTK_TREE_MODEL (state->model)));
@@ -933,44 +934,44 @@ dialog_formula_guru_init (FormulaGuruState *state)
 			  G_CALLBACK (start_editing_cb), state);
 	/* Finished set-up of treeview */
 
-	state->quote_button = glade_xml_get_widget (state->gui,
+	state->quote_button = go_gtk_builder_get_widget (state->gui,
 						    "quote-button");
-	state->array_button = glade_xml_get_widget (state->gui,
+	state->array_button = go_gtk_builder_get_widget (state->gui,
 						    "array_button");
 	gtk_widget_set_sensitive (state->array_button, TRUE);
 
-	state->ok_button = glade_xml_get_widget (state->gui, "ok_button");
+	state->ok_button = go_gtk_builder_get_widget (state->gui, "ok_button");
 	gtk_widget_set_sensitive (state->ok_button, TRUE);
 	g_signal_connect (G_OBJECT (state->ok_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_formula_guru_ok_clicked), state);
 
-	state->selector_button = glade_xml_get_widget (state->gui, "select_func");
+	state->selector_button = go_gtk_builder_get_widget (state->gui, "select_func");
 	gtk_widget_set_sensitive (state->selector_button, FALSE);
 	g_signal_connect (G_OBJECT (state->selector_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_formula_guru_selector_clicked), state);
 
-	state->clear_button = glade_xml_get_widget (state->gui, "trash");
+	state->clear_button = go_gtk_builder_get_widget (state->gui, "trash");
 	gtk_widget_set_sensitive (state->clear_button, FALSE);
 	g_signal_connect (G_OBJECT (state->clear_button),
 		"clicked",
 		G_CALLBACK (cb_dialog_formula_guru_clear_clicked), state);
 
-	state->zoom_button = glade_xml_get_widget (state->gui, "zoom");
+	state->zoom_button = go_gtk_builder_get_widget (state->gui, "zoom");
 	gtk_widget_set_sensitive (state->zoom_button, TRUE);
 	g_signal_connect (G_OBJECT (state->zoom_button),
 		"toggled",
 		G_CALLBACK (cb_dialog_formula_guru_zoom_toggled), state);
 
-	state->main_button_area = glade_xml_get_widget (state->gui, "dialog-action_area2");
+	state->main_button_area = go_gtk_builder_get_widget (state->gui, "dialog-action_area2");
 
-	g_signal_connect_swapped (G_OBJECT (glade_xml_get_widget (state->gui, "cancel_button")),
+	g_signal_connect_swapped (G_OBJECT (go_gtk_builder_get_widget (state->gui, "cancel_button")),
 		"clicked",
 		G_CALLBACK (cb_dialog_formula_guru_cancel_clicked), state);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "help_button"),
+		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_FORMULA_GURU);
 
 	wbc_gtk_attach_guru (state->wbcg, state->dialog);
@@ -1002,7 +1003,7 @@ void
 dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 {
 	SheetView *sv;
-	GladeXML  *gui;
+	GtkBuilder *gui;
 	GnmCell	  *cell;
 	GtkWidget *dialog;
 	FormulaGuruState *state;
@@ -1040,8 +1041,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 	}
 
 	/* Get the dialog and check for errors */
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"formula-guru.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("formula-guru.ui", NULL, GO_CMD_CONTEXT (wbcg));
 	if (gui == NULL)
 		return;
 
@@ -1089,7 +1089,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 		g_free (func_str);
 	}
 
-	state->dialog = glade_xml_get_widget (state->gui, "formula_guru");
+	state->dialog = go_gtk_builder_get_widget (state->gui, "formula_guru");
 
 	if (dialog_formula_guru_init (state)) {
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
@@ -1101,7 +1101,7 @@ dialog_formula_guru (WBCGtk *wbcg, GnmFunc *fd)
 	gnumeric_keyed_dialog (state->wbcg, GTK_WINDOW (state->dialog),
 			       FORMULA_GURU_KEY);
 
-	gtk_widget_show_all (GTK_DIALOG (state->dialog)->vbox);
+	gtk_widget_show_all (gtk_dialog_get_content_area (GTK_DIALOG (state->dialog)));
 	gtk_widget_realize (state->dialog);
 
 	if (fd == NULL) {
