@@ -37,18 +37,9 @@
 #include <sheet-style.h>
 #include <value.h>
 #include <wbc-gtk.h>
-#include <goffice/utils/go-file.h>
+#include <goffice/goffice.h>
 
-#include <gtk/gtkbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtksizegroup.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcellrendererpixbuf.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 
 #include <string.h>
@@ -58,7 +49,7 @@ typedef struct {
 	Workbook  *wb;
 	SheetControl *sc;
 
-	GladeXML  *gui;
+	GtkBuilder *gui;
 	GtkWidget *dialog;
 
 	GtkImage  *type_image;
@@ -83,23 +74,75 @@ dhl_free (HyperlinkState *state)
 	g_free (state);
 }
 
+static char *
+dhl_get_default_tip (char const * const target) {
+	char *default_text = _("Left click once to follow this link.\n"
+			       "Middle click once to select this cell");
+	if (target == NULL)
+		return g_strdup (default_text);
+	else
+		return g_strjoin ("\n", target, default_text, NULL);
+}
+
 static void
 dhl_set_tip (HyperlinkState* state)
 {
-	char const * tip = gnm_hlink_get_tip (state->link);
+	char const *tip = gnm_hlink_get_tip (state->link);
+	GtkTextBuffer *tb;
+	GtkWidget *w;
 
-	if (tip) {
-		GtkWidget *w = glade_xml_get_widget (state->gui, "tip-entry");
-		gtk_entry_set_text (GTK_ENTRY (w), tip);
+	if (state->is_new) {
+			w = go_gtk_builder_get_widget (state->gui, "use-default-tip");
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+			return;
 	}
+
+	if (tip != NULL) {
+		char const * const target = gnm_hlink_get_target (state->link);
+		char *default_tip = dhl_get_default_tip (target);
+
+		if (strcmp (tip, default_tip) == 0) {
+			w = go_gtk_builder_get_widget (state->gui, "use-default-tip");
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+			g_free (default_tip);
+			return;
+		} else
+			g_free (default_tip);
+	}
+	w = go_gtk_builder_get_widget (state->gui, "use-this-tip");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
+
+	tb = gtk_text_view_get_buffer
+		(GTK_TEXT_VIEW (go_gtk_builder_get_widget (state->gui, "tip-entry")));
+
+	gtk_text_buffer_set_text (tb, (tip == NULL) ? "" : tip, -1);
 }
 
-static const char *
-dhl_get_tip (HyperlinkState *state)
+static char *
+dhl_get_tip (HyperlinkState *state, char const *target)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "tip-entry");
-	const char *tip = gtk_entry_get_text (GTK_ENTRY (w));
-	return strlen (tip) > 0 ? tip : NULL;
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "use-default-tip");
+
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w)))
+		return dhl_get_default_tip (target);
+	else {
+		char *tip;
+		GtkTextBuffer *tb = gtk_text_view_get_buffer
+			(GTK_TEXT_VIEW (go_gtk_builder_get_widget (state->gui, "tip-entry")));
+		GtkTextIter start_iter, end_iter;
+
+		gtk_text_buffer_get_start_iter (tb, &start_iter);
+		gtk_text_buffer_get_end_iter (tb, &end_iter);
+
+		tip  = gtk_text_buffer_get_text (tb, &start_iter, &end_iter, FALSE);
+
+		if (tip != NULL && strlen (tip) == 0) {
+			g_free (tip);
+			tip = NULL;
+		}
+
+		return tip;
+	}
 }
 
 static void
@@ -137,7 +180,7 @@ dhl_get_target_cur_wb (HyperlinkState *state, gboolean *success)
 			ret = g_strdup (target);
 			value_release (val);
 		} else {
-			go_gtk_notice_dialog (GTK_WINDOW (state->dialog), 
+			go_gtk_notice_dialog (GTK_WINDOW (state->dialog),
 					 GTK_MESSAGE_ERROR,
 					 _("Not a range or name"));
 			gnm_expr_entry_grab_focus (gee, TRUE);
@@ -149,7 +192,7 @@ dhl_get_target_cur_wb (HyperlinkState *state, gboolean *success)
 static void
 dhl_set_target_external (HyperlinkState *state, const char* const target)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "external-link");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "external-link");
 
 	gtk_entry_set_text (GTK_ENTRY (w), target);
 }
@@ -157,7 +200,7 @@ dhl_set_target_external (HyperlinkState *state, const char* const target)
 static char *
 dhl_get_target_external (HyperlinkState *state, gboolean *success)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "external-link");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "external-link");
 	const char *target = gtk_entry_get_text (GTK_ENTRY (w));
 
 	*success = TRUE;
@@ -167,8 +210,8 @@ dhl_get_target_external (HyperlinkState *state, gboolean *success)
 static void
 dhl_set_target_email (HyperlinkState *state, const char* const target)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "email-address");
-	GtkWidget *w2 = glade_xml_get_widget (state->gui, "email-subject");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "email-address");
+	GtkWidget *w2 = go_gtk_builder_get_widget (state->gui, "email-subject");
 	gchar* cursor;
 	gchar* subject;
 	gchar* guitext;
@@ -200,8 +243,8 @@ dhl_set_target_email (HyperlinkState *state, const char* const target)
 static char*
 dhl_get_target_email (HyperlinkState *state, gboolean *success)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "email-address");
-	GtkWidget *w2 = glade_xml_get_widget (state->gui, "email-subject");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "email-address");
+	GtkWidget *w2 = go_gtk_builder_get_widget (state->gui, "email-subject");
 	const char *address = gtk_entry_get_text (GTK_ENTRY (w));
 	const char *subject = gtk_entry_get_text (GTK_ENTRY (w2));
 	gchar* enc_subj, *enc_addr;
@@ -217,8 +260,8 @@ dhl_get_target_email (HyperlinkState *state, gboolean *success)
 		result =  g_strconcat ("mailto:", enc_addr, NULL);
 	} else {
 		enc_subj = go_url_encode (subject, 0);
-		
-		result = g_strconcat ("mailto:", enc_addr, 
+
+		result = g_strconcat ("mailto:", enc_addr,
 				      "?subject=", enc_subj, NULL);
 		g_free (enc_subj);
 	}
@@ -231,7 +274,7 @@ dhl_get_target_email (HyperlinkState *state, gboolean *success)
 static void
 dhl_set_target_url (HyperlinkState *state, const char* const target)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "url");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "url");
 
 	gtk_entry_set_text (GTK_ENTRY (w), target);
 }
@@ -239,7 +282,7 @@ dhl_set_target_url (HyperlinkState *state, const char* const target)
 static char *
 dhl_get_target_url (HyperlinkState *state, gboolean *success)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, "url");
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, "url");
 	const char *target = gtk_entry_get_text (GTK_ENTRY (w));
 
 	*success = TRUE;
@@ -328,6 +371,7 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 	GnmStyle *style;
 	char *cmdname;
 	char *target;
+	char *tip;
 	gboolean success;
 
 	target = dhl_get_target (state, &success);
@@ -336,7 +380,9 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 
 	if (target) {
 		gnm_hlink_set_target (state->link, target);
-		gnm_hlink_set_tip (state->link, dhl_get_tip (state));
+		tip = dhl_get_tip (state, target);
+		gnm_hlink_set_tip (state->link, tip);
+		g_free (tip);
 		style = gnm_style_new ();
 		gnm_style_set_hlink (style, g_object_ref (state->link));
 		gnm_style_set_font_uline (style, UNDERLINE_SINGLE);
@@ -344,12 +390,12 @@ dhl_cb_ok (G_GNUC_UNUSED GtkWidget *button, HyperlinkState *state)
 
 		if (state->is_new) {
 			cmdname = _("Add Hyperlink");
-			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg), 
+			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg),
 						 style,
 						 cmdname, target);
 		} else {
 			cmdname = _("Edit Hyperlink");
-			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg), 
+			cmd_selection_hyperlink (WORKBOOK_CONTROL (state->wbcg),
 						 style,
 						 cmdname, NULL);
 			g_free (target);
@@ -372,7 +418,7 @@ dhl_setup_type (HyperlinkState *state)
 	unsigned i;
 
 	for (i = 0 ; i < G_N_ELEMENTS (type); i++) {
-		w = glade_xml_get_widget (state->gui, type[i].widget_name);
+		w = go_gtk_builder_get_widget (state->gui, type[i].widget_name);
 
 		if (!strcmp (name, type[i].name)) {
 			gtk_widget_show_all (w);
@@ -417,7 +463,7 @@ dhl_init (HyperlinkState *state)
 		"email-address-label",
 		"email-subject-label",
 		"url-label",
-		"tip-label"
+		"use-this-tip"
 	};
 	GtkWidget *w;
 	GtkSizeGroup *size_group;
@@ -429,53 +475,52 @@ dhl_init (HyperlinkState *state)
 	GtkCellRenderer *renderer;
 
 #ifdef GNM_NO_MAILTO
-	gtk_widget_hide (glade_xml_get_widget (state->gui, "email-box"));
+	gtk_widget_hide (go_gtk_builder_get_widget (state->gui, "email-box"));
 #endif
 	size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	for (i = 0 ; i < G_N_ELEMENTS (label); i++)
 		gtk_size_group_add_widget (size_group,
-			glade_xml_get_widget (state->gui, label[i]));
+					   go_gtk_builder_get_widget (state->gui, label[i]));
 
-	w  = glade_xml_get_widget (state->gui, "link-type-image");
+	w  = go_gtk_builder_get_widget (state->gui, "link-type-image");
 	state->type_image = GTK_IMAGE (w);
-	w  = glade_xml_get_widget (state->gui, "link-type-descriptor");
+	w  = go_gtk_builder_get_widget (state->gui, "link-type-descriptor");
 	state->type_descriptor = GTK_LABEL (w);
 
-	w = glade_xml_get_widget (state->gui, "internal-link-box");
+	w = go_gtk_builder_get_widget (state->gui, "internal-link-box");
 	expr_entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gtk_box_pack_end (GTK_BOX (w), GTK_WIDGET (expr_entry), TRUE, TRUE, 0);
 	gtk_entry_set_activates_default
 		(gnm_expr_entry_get_entry (expr_entry), TRUE);
 	state->internal_link_ee = expr_entry;
 
-	w = glade_xml_get_widget (state->gui, "cancel_button");
+	w = go_gtk_builder_get_widget (state->gui, "cancel_button");
 	g_signal_connect (G_OBJECT (w),
-		"clicked",
-		G_CALLBACK (dhl_cb_cancel), state);
+			  "clicked",
+			  G_CALLBACK (dhl_cb_cancel), state);
 
-	w  = glade_xml_get_widget (state->gui, "ok_button");
+	w  = go_gtk_builder_get_widget (state->gui, "ok_button");
 	g_signal_connect (G_OBJECT (w),
-		"clicked",
-		G_CALLBACK (dhl_cb_ok), state);
+			  "clicked",
+			  G_CALLBACK (dhl_cb_ok), state);
 	gtk_window_set_default (GTK_WINDOW (state->dialog), w);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "help_button"),
+		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_HYPERLINK);
 
-
 	store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
-	w  = glade_xml_get_widget (state->gui, "link-type-menu");
+	w  = go_gtk_builder_get_widget (state->gui, "link-type-menu");
 	gtk_combo_box_set_model (GTK_COMBO_BOX (w), GTK_TREE_MODEL (store));
 
 	for (i = 0 ; i < G_N_ELEMENTS (type); i++) {
 		pixbuf = gtk_widget_render_icon (w, type[i].image_name,
-											 GTK_ICON_SIZE_MENU, NULL);
+						 GTK_ICON_SIZE_MENU, NULL);
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
-					0, pixbuf,
-					1, _(type[i].label),
-					-1);
+				    0, pixbuf,
+				    1, _(type[i].label),
+				    -1);
 
 		if (strcmp (G_OBJECT_TYPE_NAME (state->link),
 			    type [i].name) == 0)
@@ -484,24 +529,31 @@ dhl_init (HyperlinkState *state)
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w),
-								renderer,
-								FALSE);
+				    renderer,
+				    FALSE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), renderer,
-									"pixbuf", 0,
-									NULL);
+					"pixbuf", 0,
+					NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w),
-								renderer,
-								TRUE);
+				    renderer,
+				    TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), renderer,
-									"text", 1,
-									NULL);
+					"text", 1,
+					NULL);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (w), select);
 
 	g_signal_connect (G_OBJECT (w), "changed",
-		G_CALLBACK (dhl_cb_menu_changed),
-		state);
+			  G_CALLBACK (dhl_cb_menu_changed),
+			  state);
+
+	gnm_link_button_and_entry (go_gtk_builder_get_widget (state->gui, "use-this-tip"),
+				   go_gtk_builder_get_widget (state->gui, "tip-entry"));
+
+	gnm_dialog_setup_destroy_handlers (GTK_DIALOG (state->dialog),
+					   state->wbcg,
+					   GNM_DIALOG_DESTROY_CURRENT_SHEET_REMOVED);
 
 	return FALSE;
 }
@@ -510,7 +562,7 @@ dhl_init (HyperlinkState *state)
 void
 dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 {
-	GladeXML *gui;
+	GtkBuilder *gui;
 	HyperlinkState* state;
 	GnmHLink	*link = NULL;
 	Sheet		*sheet;
@@ -521,8 +573,7 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 	if (gnumeric_dialog_raise_if_exists (wbcg, DIALOG_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"hyperlink.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("hyperlink.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
@@ -531,22 +582,26 @@ dialog_hyperlink (WBCGtk *wbcg, SheetControl *sc)
 	state->wb   = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 	state->sc   = sc;
 	state->gui  = gui;
-        state->dialog = glade_xml_get_widget (state->gui, "hyperlink-dialog");
+        state->dialog = go_gtk_builder_get_widget (state->gui, "hyperlink-dialog");
 
 	sheet = sc_sheet (sc);
 	for (ptr = sc_view (sc)->selections; ptr != NULL; ptr = ptr->next)
 		if (NULL != (link = sheet_style_region_contains_link (sheet, ptr->data)))
 			break;
 
-	if (link == NULL) {
-		link = g_object_new (gnm_hlink_url_get_type (), NULL);
+	/* We are creating a new link since the existing link */
+	/* may be used in many places. */
+	/* We are duplicating it here rather than in an ok handler in case */
+	/* The link is changed for a differnt cell in a different view. */
+	state->link = g_object_new (gnm_hlink_url_get_type (), NULL);
+	if (link == NULL)
 		state->is_new = TRUE;
-	} else {
-		g_object_ref (link);
+	else {
 		state->is_new = FALSE;
+		gnm_hlink_set_target (state->link, gnm_hlink_get_target (link));
+		gnm_hlink_set_tip (state->link, gnm_hlink_get_tip (link));
 	}
 
-	state->link = link;
 	if (dhl_init (state)) {
 		go_gtk_notice_dialog (wbcg_toplevel (wbcg), GTK_MESSAGE_ERROR,
 				 _("Could not create the hyperlink dialog."));
