@@ -29,6 +29,7 @@
 #include "help.h"
 #include "tool-dialogs.h"
 #include "random-generator.h"
+#include <dead-kittens.h>
 
 #include <workbook.h>
 #include <workbook-control.h>
@@ -49,7 +50,6 @@
 #include <widgets/gnumeric-expr-entry.h>
 #include <widgets/gnm-dao.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <string.h>
 
@@ -505,9 +505,14 @@ dialog_random_realized (GtkWidget *widget, RandomToolState *state)
 {
 	GtkWidget *t = state->distribution_table;
 	GtkWidget *l = state->par1_label;
+	GtkAllocation a;
+
+	gtk_widget_get_allocation (t, &a);
+	gtk_widget_set_size_request (t, a.width, a.height);
+
+	gtk_widget_get_allocation (l, &a);
+	gtk_widget_set_size_request (l, a.width, a.height);
 
-	gtk_widget_set_size_request (t, t->allocation.width, t->allocation.height);
-	gtk_widget_set_size_request (l, l->allocation.width, l->allocation.height);
 	distribution_callback (widget, state);
 }
 
@@ -693,7 +698,7 @@ random_tool_ok_clicked_cb (GtkWidget *button, RandomToolState *state)
 
 	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
 				state->base.sheet,
-				dao, data, tool_random_engine) &&
+				dao, data, tool_random_engine, TRUE) &&
 	    (button == state->base.ok_button))
 		gtk_widget_destroy (state->base.dialog);
 }
@@ -719,16 +724,16 @@ dialog_random_tool_init (RandomToolState *state)
 
 	state->distribution = UniformDistribution;
 
-	state->distribution_table = glade_xml_get_widget (state->base.gui,
+	state->distribution_table = go_gtk_builder_get_widget (state->base.gui,
 							  "distribution_table");
-	state->distribution_combo = glade_xml_get_widget (state->base.gui,
+	state->distribution_combo = go_gtk_builder_get_widget (state->base.gui,
 							  "distribution_combo");
-	state->par1_entry = glade_xml_get_widget (state->base.gui, "par1_entry");
-	state->par1_label = glade_xml_get_widget (state->base.gui, "par1_label");
-	state->par2_label = glade_xml_get_widget (state->base.gui, "par2_label");
-	state->par2_entry = glade_xml_get_widget (state->base.gui, "par2_entry");
-	state->vars_entry = glade_xml_get_widget (state->base.gui, "vars_entry");
-	state->count_entry = glade_xml_get_widget (state->base.gui, "count_entry");
+	state->par1_entry = go_gtk_builder_get_widget (state->base.gui, "par1_entry");
+	state->par1_label = go_gtk_builder_get_widget (state->base.gui, "par1_label");
+	state->par2_label = go_gtk_builder_get_widget (state->base.gui, "par2_label");
+	state->par2_entry = go_gtk_builder_get_widget (state->base.gui, "par2_entry");
+	state->vars_entry = go_gtk_builder_get_widget (state->base.gui, "vars_entry");
+	state->count_entry = go_gtk_builder_get_widget (state->base.gui, "count_entry");
 	int_to_entry (GTK_ENTRY (state->count_entry), 1);
 
 	renderer = (GtkCellRenderer*) gtk_cell_renderer_text_new();
@@ -761,7 +766,7 @@ dialog_random_tool_init (RandomToolState *state)
 		"changed",
 		G_CALLBACK (random_tool_update_sensitivity_cb), state);
 
-	table = GTK_TABLE (glade_xml_get_widget (state->base.gui, "distribution_table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (state->base.gui, "distribution_table"));
 	state->par1_expr_entry = GTK_WIDGET (gnm_expr_entry_new (state->base.wbcg, TRUE));
 	gnm_expr_entry_set_flags (GNM_EXPR_ENTRY (state->par1_expr_entry),
 				  GNM_EE_SINGLE_RANGE, GNM_EE_MASK);
@@ -840,7 +845,7 @@ dialog_random_tool (WBCGtk *wbcg, Sheet *sheet)
 
 	if (dialog_tool_init ((GenericToolState *)state, wbcg, sheet,
 			      GNUMERIC_HELP_LINK_RANDOM_GENERATOR,
-			      "random-generation.glade", "Random",
+			      "random-generation.ui", "Random",
 			      _("Could not create the Random Tool dialog."),
 			      RANDOM_KEY,
 			      G_CALLBACK (random_tool_ok_clicked_cb), NULL,
