@@ -46,7 +46,6 @@
 #include <widgets/gnumeric-cell-renderer-toggle.h>
 #include <goffice/goffice.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <string.h>
 
@@ -55,7 +54,7 @@
 typedef struct {
 	WBCGtk  *wbcg;
 
-	GladeXML  *gui;
+	GtkBuilder *gui;
 	GtkWidget *dialog;
 	GtkTreeView *sheet_list;
 	GtkListStore *model;
@@ -309,12 +308,12 @@ cb_color_changed_fore (G_GNUC_UNUSED GOComboColor *go_combo_color,
 	GnmColor *gnm_color;
 
 	g_return_if_fail (selection != NULL);
-		
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
 
 	p_gdk_color = (color == 0) ? NULL : go_color_to_gdk (color, &gdk_color);
 	gnm_color = (color == 0) ? NULL : style_color_new_gdk (&gdk_color);
-	
+
 	old_state = workbook_sheet_state_new (wb);
 
 	for (l = selected_rows; l != NULL; l = l->next) {
@@ -361,12 +360,12 @@ cb_color_changed_back (G_GNUC_UNUSED GOComboColor *go_combo_color,
 	GnmColor *gnm_color;
 
 	g_return_if_fail (selection != NULL);
-		
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
 
 	p_gdk_color = (color == 0) ? NULL : go_color_to_gdk (color, &gdk_color);
 	gnm_color = (color == 0) ? NULL : style_color_new_gdk (&gdk_color);
-	
+
 	old_state = workbook_sheet_state_new (wb);
 
 	for (l = selected_rows; l != NULL; l = l->next) {
@@ -458,7 +457,7 @@ cb_selection_changed (G_GNUC_UNUSED GtkTreeSelection *ignored,
 
 	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model),
 				 &iter, (GtkTreePath *) selected_rows->data);
-	
+
 	gtk_tree_model_get (GTK_TREE_MODEL (state->model), &iter,
 			    SHEET_POINTER, &sheet,
 			    BACKGROUND_COLOUR, &back,
@@ -483,13 +482,13 @@ cb_selection_changed (G_GNUC_UNUSED GtkTreeSelection *ignored,
 	has_iter = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (state->model), &iter);
 	g_return_if_fail (has_iter);
 	gtk_widget_set_sensitive (state->up_btn,
-				  single_sel && 
+				  single_sel &&
 				  !gtk_tree_selection_iter_is_selected (selection, &iter));
 	gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (state->model), &iter, NULL,
-				       gtk_tree_model_iter_n_children 
+				       gtk_tree_model_iter_n_children
 				       (GTK_TREE_MODEL (state->model), NULL) - 1);
 	gtk_widget_set_sensitive (state->down_btn,
-				  single_sel && 
+				  single_sel &&
 				  !gtk_tree_selection_iter_is_selected (selection, &iter));
 
 	if (sheet != NULL)
@@ -508,9 +507,9 @@ cb_toggled_lock (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 	GtkTreeModel *model = GTK_TREE_MODEL (state->model);
 	GtkTreeIter iter;
 	GtkTreePath *path = gtk_tree_path_new_from_string (path_string);
-	gboolean is_locked;
-	Sheet *this_sheet;
-	WorkbookSheetState *old_state;
+	gboolean is_locked = TRUE;
+	Sheet *this_sheet = NULL;
+	WorkbookSheetState *old_state = NULL;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
 	Workbook *wb = wb_control_get_workbook (wbc);
 
@@ -533,6 +532,8 @@ cb_toggled_lock (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 		}
 	} else {
 		g_warning ("Did not get a valid iterator");
+		gtk_tree_path_free (path);
+		return;
 	}
 	gtk_tree_path_free (path);
 
@@ -552,9 +553,9 @@ cb_toggled_direction (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 	GtkTreeModel *model = GTK_TREE_MODEL (state->model);
 	GtkTreePath  *path  = gtk_tree_path_new_from_string (path_string);
 	GtkTreeIter iter;
-	gboolean is_rtl;
-	Sheet *this_sheet;
-	WorkbookSheetState *old_state;
+	gboolean is_rtl = TRUE;
+	Sheet *this_sheet = NULL;
+	WorkbookSheetState *old_state = NULL;
 	WorkbookControl *wbc = WORKBOOK_CONTROL (state->wbcg);
 	Workbook *wb = wb_control_get_workbook (wbc);
 
@@ -571,6 +572,8 @@ cb_toggled_direction (G_GNUC_UNUSED GtkCellRendererToggle *cell,
 			 -1);
 	} else {
 		g_warning ("Did not get a valid iterator");
+		gtk_tree_path_free (path);
+		return;
 	}
 
 	gtk_tree_path_free (path);
@@ -658,7 +661,7 @@ sheet_selection_can_toggle(GtkTreeSelection *selection,
 	GtkTreeIter iter;
 	gboolean is_visible;
 
-	if (path_currently_selected || 
+	if (path_currently_selected ||
 	    !gtk_tree_model_get_iter (model, &iter, path))
 		return TRUE;
 
@@ -674,7 +677,7 @@ create_sheet_list (SheetManager *state)
 {
 	GtkTreeViewColumn *column;
 	GtkTreeSelection  *selection;
-	GtkWidget *scrolled = glade_xml_get_widget (state->gui, "scrolled");
+	GtkWidget *scrolled = go_gtk_builder_get_widget (state->gui, "scrolled");
 	GtkCellRenderer *renderer;
 
 	state->model = gtk_list_store_new (NUM_COLUMNS,
@@ -879,10 +882,10 @@ cb_item_move (SheetManager *state, gnm_iter_search_t iter_search)
 	GtkTreeSelection  *selection = gtk_tree_view_get_selection (state->sheet_list);
 	GtkTreeIter  a, b;
 	GList *selected_rows;
-	
+
 	g_return_if_fail (selection != NULL);
 	g_return_if_fail (gtk_tree_selection_count_selected_rows (selection) == 1);
-	
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
 	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model),
 				 &a, (GtkTreePath *) selected_rows->data);
@@ -922,12 +925,12 @@ cb_add_clicked (G_GNUC_UNUSED GtkWidget *ignore, SheetManager *state)
 
 	g_return_if_fail (selection != NULL);
 	g_return_if_fail (gtk_tree_selection_count_selected_rows (selection) == 1);
-	
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
 	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model),
 				 &sel_iter, (GtkTreePath *) selected_rows->data);
 	go_list_free_custom (selected_rows, (GFreeFunc) gtk_tree_path_free);
-	
+
 	gtk_tree_model_get (GTK_TREE_MODEL (state->model), &sel_iter,
 			    SHEET_POINTER, &old_sheet,
 			    -1);
@@ -1001,7 +1004,7 @@ cb_duplicate_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 
 	g_return_if_fail (selection != NULL);
 	g_return_if_fail (gtk_tree_selection_count_selected_rows (selection) == 1);
-	
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
 	gtk_tree_model_get_iter (GTK_TREE_MODEL (state->model),
 				 &sel_iter, (GtkTreePath *) selected_rows->data);
@@ -1044,11 +1047,11 @@ cb_delete_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 	Workbook *wb = wb_control_get_workbook (wbc);
 
 	g_return_if_fail (selection != NULL);
-		
+
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, NULL);
-	
-	for (l = selected_rows; l != NULL; l = l->next) 
-		l->data = gtk_tree_row_reference_new (GTK_TREE_MODEL (state->model), 
+
+	for (l = selected_rows; l != NULL; l = l->next)
+		l->data = gtk_tree_row_reference_new (GTK_TREE_MODEL (state->model),
 						      (GtkTreePath *) l->data);
 	workbook_signals_block (state);
 	old_state = workbook_sheet_state_new (wb);
@@ -1069,7 +1072,7 @@ cb_delete_clicked (G_GNUC_UNUSED GtkWidget *ignore,
 			workbook_sheet_delete (sheet);
 		}
 	}
-	
+
 	cmd_reorganize_sheets (wbc, old_state, NULL);
 	update_undo (state, wbc);
 	workbook_signals_unblock (state);
@@ -1414,20 +1417,24 @@ cb_adv_check_toggled (G_GNUC_UNUSED GtkToggleButton *ignored,
 	gtk_tree_view_column_set_visible (state->row_max_column, visible);
 }
 
+static void
+destroy_cb (GObject *obj)
+{
+	g_object_set_data (obj, "state", NULL);
+}
 
 void
 dialog_sheet_order (WBCGtk *wbcg)
 {
 	SheetManager *state;
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkTable *table;
 	GOColorGroup *cg;
 	Workbook *wb;
 
 	g_return_if_fail (wbcg != NULL);
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"sheet-order.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("sheet-order.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
@@ -1446,21 +1453,21 @@ dialog_sheet_order (WBCGtk *wbcg)
 	state = g_new0 (SheetManager, 1);
 	state->gui = gui;
 	state->wbcg = wbcg;
-	state->dialog     = glade_xml_get_widget (gui, "sheet-order-dialog");
-	state->warning     = glade_xml_get_widget (gui, "warning");
-	state->up_btn     = glade_xml_get_widget (gui, "up_button");
-	state->down_btn   = glade_xml_get_widget (gui, "down_button");
-	state->add_btn   = glade_xml_get_widget (gui, "add_button");
-	state->append_btn   = glade_xml_get_widget (gui, "append_button");
-	state->duplicate_btn   = glade_xml_get_widget (gui, "duplicate_button");
-	state->delete_btn   = glade_xml_get_widget (gui, "delete_button");
+	state->dialog     = go_gtk_builder_get_widget (gui, "sheet-order-dialog");
+	state->warning     = go_gtk_builder_get_widget (gui, "warning");
+	state->up_btn     = go_gtk_builder_get_widget (gui, "up_button");
+	state->down_btn   = go_gtk_builder_get_widget (gui, "down_button");
+	state->add_btn   = go_gtk_builder_get_widget (gui, "add_button");
+	state->append_btn   = go_gtk_builder_get_widget (gui, "append_button");
+	state->duplicate_btn   = go_gtk_builder_get_widget (gui, "duplicate_button");
+	state->delete_btn   = go_gtk_builder_get_widget (gui, "delete_button");
 
-	state->apply_names_btn  = glade_xml_get_widget (gui, "ok_button");
-	state->sort_asc_btn  = glade_xml_get_widget (gui, "sort-asc-button");
-	state->sort_desc_btn  = glade_xml_get_widget (gui, "sort-desc-button");
-	state->undo_btn  = glade_xml_get_widget (gui, "undo-button");
-	state->cancel_btn  = glade_xml_get_widget (gui, "cancel_button");
-	state->advanced_check  = glade_xml_get_widget (gui, "advanced-check");
+	state->apply_names_btn  = go_gtk_builder_get_widget (gui, "ok_button");
+	state->sort_asc_btn  = go_gtk_builder_get_widget (gui, "sort-asc-button");
+	state->sort_desc_btn  = go_gtk_builder_get_widget (gui, "sort-desc-button");
+	state->undo_btn  = go_gtk_builder_get_widget (gui, "undo-button");
+	state->cancel_btn  = go_gtk_builder_get_widget (gui, "cancel_button");
+	state->advanced_check  = go_gtk_builder_get_widget (gui, "advanced-check");
 	state->initial_colors_set = FALSE;
 	state->image_padlock =  gtk_widget_render_icon (state->dialog,
                                              "Gnumeric_Protection_Yes",
@@ -1493,7 +1500,7 @@ dialog_sheet_order (WBCGtk *wbcg)
 		"sheet_deleted", G_CALLBACK (cb_sheet_deleted),
 		state);
 
-	table = GTK_TABLE (glade_xml_get_widget (gui,"sheet_order_buttons_table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (gui,"sheet_order_buttons_table"));
 	cg = go_color_group_fetch ("back_color_group",
 		wb_control_view (WORKBOOK_CONTROL (wbcg)));
 	state->ccombo_back = go_combo_color_new (
@@ -1540,7 +1547,7 @@ dialog_sheet_order (WBCGtk *wbcg)
 	cb_adv_check_toggled (NULL, state);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "help_button"),
+		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_SHEET_MANAGER);
 
 	gtk_widget_set_sensitive (state->undo_btn, wb->undo_commands != NULL);
@@ -1550,6 +1557,7 @@ dialog_sheet_order (WBCGtk *wbcg)
 	wbc_gtk_attach_guru (state->wbcg, GTK_WIDGET (state->dialog));
 	g_object_set_data_full (G_OBJECT (state->dialog),
 		"state", state, (GDestroyNotify) cb_sheet_order_destroy);
+	g_signal_connect (G_OBJECT (state->dialog), "destroy", G_CALLBACK (destroy_cb), NULL);
 
 	gnumeric_restore_window_geometry (GTK_WINDOW (state->dialog),
 					  SHEET_ORDER_KEY);
