@@ -28,6 +28,7 @@
 #include <gnumeric.h>
 #include "dialogs.h"
 #include "help.h"
+#include <dead-kittens.h>
 
 #include <gui-util.h>
 #include <func.h>
@@ -35,6 +36,7 @@
 #include <value.h>
 #include <cell.h>
 #include <sheet.h>
+#include <sheet-view.h>
 #include <expr.h>
 #include <wbc-gtk.h>
 #include <workbook.h>
@@ -42,10 +44,10 @@
 #include <ranges.h>
 #include <commands.h>
 #include <clipboard.h>
+#include <selection.h>
 #include <tools/gnm-solver.h>
 #include <widgets/gnumeric-expr-entry.h>
 
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <goffice/goffice.h>
 #include <string.h>
@@ -54,7 +56,7 @@
 #define SOLVER_KEY            "solver-dialog"
 
 typedef struct {
-	GladeXML            *gui;
+	GtkBuilder          *gui;
 	GtkWidget           *dialog;
 	GnmExprEntry	    *target_entry;
 	GnmExprEntry	    *change_cell_entry;
@@ -338,7 +340,7 @@ cb_dialog_model_type_clicked (G_GNUC_UNUSED GtkWidget *button,
 	GnmSolverModelType type;
 	gboolean any;
 
-	type = gnumeric_glade_group_value (state->gui, model_type_group);
+	type = gnm_gui_group_value (state->gui, model_type_group);
 	any = fill_algorithm_combo (state, type);
 
 	if (!any) {
@@ -371,7 +373,7 @@ set_params (Sheet *sheet, GnmSolverParameters *params)
 
 #define GET_BOOL_ENTRY(name_, field_)					\
 	do {								\
-		GtkWidget *w_ = glade_xml_get_widget (state->gui, (name_)); \
+		GtkWidget *w_ = go_gtk_builder_get_widget (state->gui, (name_)); \
 		param->field_ = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w_)); \
 	} while (0)
 
@@ -399,9 +401,9 @@ extract_settings (SolverState *state)
 	target_cell = gnm_solver_param_get_target_cell (param);
 
 	param->problem_type =
-		gnumeric_glade_group_value (state->gui, problem_type_group);
+		gnm_gui_group_value (state->gui, problem_type_group);
 	param->options.model_type =
-		gnumeric_glade_group_value (state->gui, model_type_group);
+		gnm_gui_group_value (state->gui, model_type_group);
 
 	if (gtk_combo_box_get_active_iter (state->algorithm_combo, &iter)) {
 		gtk_tree_model_get (gtk_combo_box_get_model (state->algorithm_combo),
@@ -627,12 +629,13 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 	GnmSolverResult *res = NULL;
 	int y;
 
-	sol = param->options.algorithm
-		? gnm_solver_factory_create (param->options.algorithm, param)
-		: NULL;
+	sol = gnm_solver_factory_functional (param->options.algorithm,
+					     state->wbcg)
+	    ? gnm_solver_factory_create (param->options.algorithm, param)
+	    : NULL;
 	if (!sol) {
 		go_gtk_notice_dialog (top, GTK_MESSAGE_ERROR,
-				      _("No suitable solver available."));
+				      _("The chosen solver is not functional."));
 		goto fail;
 	}
 
@@ -686,9 +689,10 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 		gtk_widget_ensure_style (w);
 		gtk_widget_set_size_request
 			(w,
-			 go_pango_measure_string (context,
-						  w->style->font_desc,
-						  "0") * (5 + GNM_DIG),
+			 go_pango_measure_string
+			 (context,
+			  gtk_widget_get_style (w)->font_desc,
+			  "0") * (5 + GNM_DIG),
 			 -1);
 		gtk_table_attach_defaults (GTK_TABLE (table),
 					   w, 1, 2, y, y + 1);
@@ -701,7 +705,8 @@ run_solver (SolverState *state, GnmSolverParameters *param)
 		}
 	}
 
-	gtk_box_pack_start (GTK_BOX (dialog->vbox), table, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)),
+			    table, TRUE, TRUE, 0);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 
 	state->run.sig_notify_result =
@@ -881,7 +886,7 @@ cb_dialog_solve_clicked (G_GNUC_UNUSED GtkWidget *button,
 
 #define INIT_BOOL_ENTRY(name_, field_)					\
 do {									\
-	GtkWidget *w_ = glade_xml_get_widget (state->gui, (name_));	\
+	GtkWidget *w_ = go_gtk_builder_get_widget (state->gui, (name_));	\
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w_),		\
 				      param->field_);			\
 } while (0)
@@ -909,46 +914,45 @@ dialog_init (SolverState *state)
 
 	param = state->sheet->solver_parameters;
 
-	state->gui = gnm_glade_xml_new (GO_CMD_CONTEXT (state->wbcg),
-		"solver.glade", NULL, NULL);
+	state->gui = gnm_gtk_builder_new ("solver.ui", NULL, GO_CMD_CONTEXT (state->wbcg));
         if (state->gui == NULL)
                 return TRUE;
 
-	state->dialog = glade_xml_get_widget (state->gui, "Solver");
+	state->dialog = go_gtk_builder_get_widget (state->gui, "Solver");
         if (state->dialog == NULL)
                 return TRUE;
 
 /*  buttons  */
-	state->solve_button  = glade_xml_get_widget (state->gui, "solvebutton");
+	state->solve_button  = go_gtk_builder_get_widget (state->gui, "solvebutton");
 	g_signal_connect (G_OBJECT (state->solve_button), "clicked",
 			  G_CALLBACK (cb_dialog_solve_clicked), state);
 
-	state->close_button  = glade_xml_get_widget (state->gui, "closebutton");
+	state->close_button  = go_gtk_builder_get_widget (state->gui, "closebutton");
 	g_signal_connect (G_OBJECT (state->close_button), "clicked",
 			  G_CALLBACK (cb_dialog_close_clicked), state);
 
-	gnumeric_init_help_button (glade_xml_get_widget (state->gui,
+	gnumeric_init_help_button (go_gtk_builder_get_widget (state->gui,
 							 "helpbutton"),
 				   GNUMERIC_HELP_LINK_SOLVER);
 
-	state->add_button  = glade_xml_get_widget (state->gui, "addbutton");
+	state->add_button  = go_gtk_builder_get_widget (state->gui, "addbutton");
 	gtk_button_set_alignment (GTK_BUTTON (state->add_button), 0.5, .5);
 	g_signal_connect_swapped (G_OBJECT (state->add_button), "clicked",
 		G_CALLBACK (cb_dialog_add_clicked), state);
 
-	state->change_button = glade_xml_get_widget (state->gui,
+	state->change_button = go_gtk_builder_get_widget (state->gui,
 						     "changebutton");
 	g_signal_connect (G_OBJECT (state->change_button), "clicked",
 			  G_CALLBACK (cb_dialog_change_clicked), state);
 
-	state->delete_button = glade_xml_get_widget (state->gui,
+	state->delete_button = go_gtk_builder_get_widget (state->gui,
 						     "deletebutton");
 	gtk_button_set_alignment (GTK_BUTTON (state->delete_button), 0.5, .5);
 	g_signal_connect (G_OBJECT (state->delete_button), "clicked",
 			  G_CALLBACK (cb_dialog_delete_clicked), state);
 
 	/* target_entry */
-	table = GTK_TABLE (glade_xml_get_widget (state->gui,
+	table = GTK_TABLE (go_gtk_builder_get_widget (state->gui,
 						 "parameter_table"));
 	state->target_entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->target_entry,
@@ -966,7 +970,7 @@ dialog_init (SolverState *state)
 				state);
 
 	/* change_cell_entry */
-	table = GTK_TABLE (glade_xml_get_widget (state->gui,
+	table = GTK_TABLE (go_gtk_builder_get_widget (state->gui,
 						 "parameter_table"));
 	state->change_cell_entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->change_cell_entry,
@@ -984,7 +988,7 @@ dialog_init (SolverState *state)
 
 	/* Algorithm */
 	state->algorithm_combo = GTK_COMBO_BOX
-		(glade_xml_get_widget (state->gui, "algorithm_combo"));
+		(go_gtk_builder_get_widget (state->gui, "algorithm_combo"));
 	renderer = (GtkCellRenderer*) gtk_cell_renderer_text_new();
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (state->algorithm_combo), renderer, TRUE);
 	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (state->algorithm_combo), renderer,
@@ -994,7 +998,7 @@ dialog_init (SolverState *state)
 
 	for (i = 0; model_type_group[i]; i++) {
 		const char *bname = model_type_group[i];
-		GtkWidget *w = glade_xml_get_widget(state->gui, bname);
+		GtkWidget *w = go_gtk_builder_get_widget(state->gui, bname);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 					      param->options.model_type ==
 					      (GnmSolverModelType)i);
@@ -1003,18 +1007,18 @@ dialog_init (SolverState *state)
 	}
 
 	/* Options */
-	state->max_iter_entry = glade_xml_get_widget (state->gui,
+	state->max_iter_entry = go_gtk_builder_get_widget (state->gui,
 						      "max_iter_entry");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->max_iter_entry),
 				   param->options.max_iter);
 
-	state->max_time_entry = glade_xml_get_widget (state->gui,
+	state->max_time_entry = go_gtk_builder_get_widget (state->gui,
 						      "max_time_entry");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (state->max_time_entry),
 				   param->options.max_time_sec);
 
 /* lhs_entry */
-	table = GTK_TABLE (glade_xml_get_widget (state->gui, "edit-table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (state->gui, "edit-table"));
 	state->lhs.entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->lhs.entry,
 		GNM_EE_SINGLE_RANGE |
@@ -1024,7 +1028,7 @@ dialog_init (SolverState *state)
 			  0, 1, 1, 2,
 			  GTK_EXPAND | GTK_FILL, 0,
 			  0, 0);
-	state->lhs.label = glade_xml_get_widget (state->gui, "lhs_label");
+	state->lhs.label = go_gtk_builder_get_widget (state->gui, "lhs_label");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (state->lhs.label),
 		GTK_WIDGET (state->lhs.entry));
 	gtk_widget_show (GTK_WIDGET (state->lhs.entry));
@@ -1036,7 +1040,7 @@ dialog_init (SolverState *state)
 		"activate", G_CALLBACK (cb_dialog_add_clicked), state);
 
 /* rhs_entry */
-	table = GTK_TABLE (glade_xml_get_widget (state->gui, "edit-table"));
+	table = GTK_TABLE (go_gtk_builder_get_widget (state->gui, "edit-table"));
 	state->rhs.entry = gnm_expr_entry_new (state->wbcg, TRUE);
 	gnm_expr_entry_set_flags (state->rhs.entry,
 				  GNM_EE_SINGLE_RANGE |
@@ -1048,7 +1052,7 @@ dialog_init (SolverState *state)
 			  2, 3, 1, 2,
 			  GTK_EXPAND | GTK_FILL, 0, 0, 0);
 	gtk_widget_show (GTK_WIDGET (state->rhs.entry));
-	state->rhs.label = glade_xml_get_widget (state->gui, "rhs_label");
+	state->rhs.label = go_gtk_builder_get_widget (state->gui, "rhs_label");
 	gtk_label_set_mnemonic_widget (
 		GTK_LABEL (state->rhs.label), GTK_WIDGET (state->rhs.entry));
 	g_signal_connect_after (G_OBJECT (state->rhs.entry),
@@ -1060,14 +1064,14 @@ dialog_init (SolverState *state)
 
 /* type_menu */
 	state->type_combo = GTK_COMBO_BOX
-		(glade_xml_get_widget (state->gui, "type_menu"));
+		(go_gtk_builder_get_widget (state->gui, "type_menu"));
 	gtk_combo_box_set_active (state->type_combo, 0);
 	g_signal_connect (state->type_combo, "changed",
 			  G_CALLBACK (dialog_set_sec_button_sensitivity),
 			  state);
 
 /* constraint_list */
-	state->constraint_list = GTK_TREE_VIEW (glade_xml_get_widget
+	state->constraint_list = GTK_TREE_VIEW (go_gtk_builder_get_widget
 					    (state->gui, "constraint_list"));
 
 	state->constr = NULL;
@@ -1126,27 +1130,37 @@ dialog_init (SolverState *state)
 	if (target_cell)
 		gnm_expr_entry_load_from_text (state->target_entry,
 					       cell_name (target_cell));
+	else {
+		SheetView *sv = wb_control_cur_sheet_view
+			(WORKBOOK_CONTROL (state->wbcg));
+		if (sv) {
+			GnmRange first = {sv->edit_pos, sv->edit_pos};
+			gnm_expr_entry_load_from_range (state->target_entry,
+							state->sheet, &first);
+		}
+	}
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "max_button")),
+		go_gtk_builder_get_widget(state->gui, "max_button")),
 			param->problem_type == GNM_SOLVER_MAXIMIZE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "min_button")),
+		go_gtk_builder_get_widget(state->gui, "min_button")),
 			param->problem_type == GNM_SOLVER_MINIMIZE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "no_scenario")),
+		go_gtk_builder_get_widget(state->gui, "no_scenario")),
 			! param->options.add_scenario);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (
-		glade_xml_get_widget(state->gui, "optimal_scenario")),
+		go_gtk_builder_get_widget(state->gui, "optimal_scenario")),
 			param->options.add_scenario);
 
-	state->scenario_name_entry = glade_xml_get_widget
+	state->scenario_name_entry = go_gtk_builder_get_widget
 		(state->gui, "scenario_name_entry");
 	gtk_entry_set_text (GTK_ENTRY (state->scenario_name_entry),
 			    param->options.scenario_name);
 
 /* Done */
 	gnm_expr_entry_grab_focus (state->target_entry, FALSE);
+	wbcg_set_entry (state->wbcg, state->target_entry);
 
 	dialog_set_main_button_sensitivity (NULL, state);
 	dialog_set_sec_button_sensitivity (NULL, state);
@@ -1178,19 +1192,29 @@ dialog_solver (WBCGtk *wbcg, Sheet *sheet)
 {
         SolverState *state;
 	GnmSolverParameters *old_params = sheet->solver_parameters;
+	gboolean got_it;
+	int pass;
 
 	/* Only pop up one copy per workbook */
 	if (gnumeric_dialog_raise_if_exists (wbcg, SOLVER_KEY))
 		return;
 
-	/* First time around, pick a functional algorithm.  */
-	if (!gnm_solver_factory_functional (old_params->options.algorithm)) {
+	/*
+	 * First time around, pick a functional algorithm preferably one we
+	 * can determine is functional without asking the user anything.
+	 */
+	got_it = gnm_solver_factory_functional (old_params->options.algorithm,
+						NULL);
+	for (pass = 1; !got_it && pass <= 2; pass++) {
 		GSList *l;
+		WBCGtk *wbcg2 = pass == 2 ? wbcg : NULL;
+
 		for (l = gnm_solver_db_get (); l; l = l->next) {
 			GnmSolverFactory *factory = l->data;
 			if (old_params->options.model_type != factory->type)
 				continue;
-			if (gnm_solver_factory_functional (factory)) {
+			if (gnm_solver_factory_functional (factory, wbcg2)) {
+				got_it = TRUE;
 				gnm_solver_param_set_algorithm (old_params,
 								factory);
 				break;
