@@ -42,7 +42,7 @@ enum {
 };
 
 typedef struct {
-	GladeXML	*gui;
+	GtkBuilder	*gui;
 	GtkWidget	*dialog;
 	GtkWidget	*notebook;
 	GtkWidget	*ok_button;
@@ -71,8 +71,8 @@ cb_widget_changed (GtkWidget *widget, AttrState *state)
 {
 	char const *key;
 
-	key = g_object_get_data (G_OBJECT (widget), "GNUMERIC:VIEWPROPERTY"); 
-	g_object_set (G_OBJECT (state->wbv), 
+	key = g_object_get_data (G_OBJECT (widget), "GNUMERIC:VIEWPROPERTY");
+	g_object_set (G_OBJECT (state->wbv),
 		      key, gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)),
 		      NULL);
 }
@@ -102,10 +102,10 @@ cb_attr_dialog_dialog_destroy (AttrState *state)
 static void
 attr_dialog_init_toggle (AttrState *state, char const *name, char const *key)
 {
-	GtkWidget *w = glade_xml_get_widget (state->gui, name);
+	GtkWidget *w = go_gtk_builder_get_widget (state->gui, name);
 	gboolean val = FALSE;
 
-	g_object_get (G_OBJECT (state->wbv), key, &val, NULL); 
+	g_object_get (G_OBJECT (state->wbv), key, &val, NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), val);
 
 	g_signal_connect (G_OBJECT (w),
@@ -118,13 +118,13 @@ attr_dialog_init_toggle (AttrState *state, char const *name, char const *key)
 static void
 attr_dialog_init_widget_page (AttrState *state)
 {
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::show_horizontal_scrollbar", "show_horizontal_scrollbar");
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::show_vertical_scrollbar", "show_vertical_scrollbar");
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::show_notebook_tabs", "show_notebook_tabs");
 }
@@ -132,7 +132,7 @@ attr_dialog_init_widget_page (AttrState *state)
 static void
 attr_dialog_init_autocompletion_page (AttrState *state)
 {
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::do_auto_completion", "do_auto_completion");
 }
@@ -140,7 +140,7 @@ attr_dialog_init_autocompletion_page (AttrState *state)
 static void
 attr_dialog_init_cell_marker_page (AttrState *state)
 {
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::show_function_cell_markers", "show_function_cell_markers");
 }
@@ -148,7 +148,7 @@ attr_dialog_init_cell_marker_page (AttrState *state)
 static void
 attr_dialog_init_protection_page (AttrState *state)
 {
-	attr_dialog_init_toggle 
+	attr_dialog_init_toggle
 		(state,
 		 "WorkbookView::workbook_protected", "protected");
 }
@@ -203,7 +203,7 @@ typedef struct {
 	GtkTreePath *path;
 } page_search_t;
 
-static gboolean   
+static gboolean
 attr_dialog_select_page_search (GtkTreeModel *model,
 				GtkTreePath *path,
 				GtkTreeIter *iter,
@@ -258,7 +258,7 @@ cb_attr_dialog_selection_changed (GtkTreeSelection *selection,
 static void
 attr_dialog_impl (AttrState *state)
 {
-	GtkWidget *dialog = glade_xml_get_widget (state->gui, "WorkbookAttr");
+	GtkWidget *dialog = go_gtk_builder_get_widget (state->gui, "WorkbookAttr");
 	GtkTreeViewColumn *column;
 	GtkTreeSelection  *selection;
 	int i;
@@ -267,10 +267,10 @@ attr_dialog_impl (AttrState *state)
 
 	/* Initialize */
 	state->dialog			= dialog;
-	state->notebook                 = glade_xml_get_widget (state->gui, "notebook");
+	state->notebook                 = go_gtk_builder_get_widget (state->gui, "notebook");
 	state->destroying               = FALSE;
 
-	state->tview = GTK_TREE_VIEW(glade_xml_get_widget (state->gui, "itemlist"));
+	state->tview = GTK_TREE_VIEW(go_gtk_builder_get_widget (state->gui, "itemlist"));
 	state->store = gtk_tree_store_new (NUM_COLUMNS,
 					   GDK_TYPE_PIXBUF,
 					   G_TYPE_STRING,
@@ -297,18 +297,18 @@ attr_dialog_impl (AttrState *state)
 	for (i = 0; page_info[i].page > -1; i++) {
 		const page_info_t *this_page =  &page_info[i];
 		this_page->page_initializer (state);
-		attr_dialog_add_item (state, this_page->page_name, this_page->icon_name, 
+		attr_dialog_add_item (state, this_page->page_name, this_page->icon_name,
 					       this_page->page, this_page->parent_path);
 	}
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (state->store), ITEM_NAME, GTK_SORT_ASCENDING);
 
-	g_signal_connect (G_OBJECT (glade_xml_get_widget (state->gui, "close_button")),
+	g_signal_connect (G_OBJECT (go_gtk_builder_get_widget (state->gui, "close_button")),
 			  "clicked",
 			  G_CALLBACK (cb_attr_dialog_dialog_close), state);
 
 	gnumeric_init_help_button (
-		glade_xml_get_widget (state->gui, "help_button"),
+		go_gtk_builder_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_WORKBOOK_ATTRIBUTE);
 
 	/* a candidate for merging into attach guru */
@@ -323,7 +323,7 @@ attr_dialog_impl (AttrState *state)
 void
 dialog_workbook_attr (WBCGtk *wbcg)
 {
-	GladeXML     *gui;
+	GtkBuilder   *gui;
 	AttrState    *state;
 
 	g_return_if_fail (wbcg != NULL);
@@ -331,8 +331,7 @@ dialog_workbook_attr (WBCGtk *wbcg)
 	if (gnumeric_dialog_raise_if_exists (wbcg, WORKBOOK_ATTRIBUTE_KEY))
 		return;
 
-	gui = gnm_glade_xml_new (GO_CMD_CONTEXT (wbcg),
-		"workbook-attr.glade", NULL, NULL);
+	gui = gnm_gtk_builder_new ("workbook-attr.ui", NULL, GO_CMD_CONTEXT (wbcg));
         if (gui == NULL)
                 return;
 
