@@ -649,13 +649,32 @@ gnm_func_sanity_check1 (GnmFunc const *fd)
 				g_hash_table_insert (allargs, argname, argname);
 			break;
 		}
-		case GNM_FUNC_HELP_DESCRIPTION:
+		case GNM_FUNC_HELP_DESCRIPTION: {
+			const char *p;
+
 			if (check_argument_refs (h->text, fd)) {
 				g_printerr ("%s: Invalid argument reference in description\n",
 					    fd->name);
 				res = 1;
 			}
+
+			p = h->text;
+			while (g_ascii_isupper (*p) ||
+			       (p != h->text && (*p == '_' ||
+						 *p == '.' ||
+						 g_ascii_isdigit (*p))))
+				p++;
+			if (*p == ' ' &&
+			    p - h->text >= 2 &&
+			    strncmp (h->text, "CP1252", 6) != 0) {
+				if (g_ascii_strncasecmp (h->text, fd->name, nlen)) {
+					g_printerr ("%s: Wrong function name in description\n",
+						    fd->name);
+					res = 1;
+				}
+			}
 			break;
+		}
 
 		case GNM_FUNC_HELP_EXAMPLES:
 			if (h->text[0] == '=') {
@@ -1479,7 +1498,7 @@ function_call_with_exprs (GnmFuncEvalInfo *ei, GnmExprEvalFlags flags)
 	/* Optimization for IF when implicit iteration is not used.  */
 	if (ei->func_call->func->fn.args.func == gnumeric_if &&
 	    iter_count == -1)
-		return gnumeric_if2 (ei, argc, argv);
+		return gnumeric_if2 (ei, argc, argv, flags);
 
 	for (i = 0; i < argc; i++) {
 		char arg_type = fn_def->fn.args.arg_types[i];
