@@ -920,8 +920,8 @@ gnm_plugins_init (GOCmdContext *context)
 	char const *env_var;
 	GSList *dir_list = go_slist_create (
 		g_build_filename (gnm_sys_lib_dir (), PLUGIN_SUBDIR, NULL),
-		(gnm_usr_dir () == NULL ? NULL :
-			g_build_filename (gnm_usr_dir (), PLUGIN_SUBDIR, NULL)),
+		(gnm_usr_dir (TRUE) == NULL ? NULL :
+			g_build_filename (gnm_usr_dir (TRUE), PLUGIN_SUBDIR, NULL)),
 		NULL);
 	dir_list = g_slist_concat (dir_list,
 				   go_string_slist_copy (gnm_conf_get_plugins_extra_dirs ()));
