@@ -24,7 +24,7 @@
 #include "gnumeric.h"
 #include "gnm-so-polygon.h"
 #include "sheet-object-impl.h"
-#include "xml-io.h"
+#include "sheet.h"
 #include "parse-util.h"
 
 #include <goffice/goffice.h>
@@ -112,7 +112,8 @@ static SheetObjectClass *gnm_so_polygon_parent_class;
 enum {
 	SOP_PROP_0,
 	SOP_PROP_STYLE,
-	SOP_PROP_POINTS
+	SOP_PROP_POINTS,
+	SOP_PROP_DOCUMENT
 };
 
 static GOStyle *
@@ -120,12 +121,12 @@ sop_default_style (void)
 {
 	GOStyle *res = go_style_new ();
 	res->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
-	res->outline.width = 0; /* hairline */
-	res->outline.color = RGBA_BLACK;
-	res->outline.dash_type = GO_LINE_SOLID; /* anything but 0 */
-	res->outline.join = CAIRO_LINE_JOIN_ROUND;
+	res->line.width = 0; /* hairline */
+	res->line.color = GO_COLOR_BLACK;
+	res->line.dash_type = GO_LINE_SOLID; /* anything but 0 */
+	res->line.join = CAIRO_LINE_JOIN_ROUND;
 	res->fill.type = GO_STYLE_FILL_PATTERN;
-	go_pattern_set_solid (&res->fill.pattern, RGBA_WHITE);
+	go_pattern_set_solid (&res->fill.pattern, GO_COLOR_WHITE);
 	return res;
 }
 
@@ -175,26 +176,6 @@ gnm_so_polygon_draw_cairo (SheetObject const *so, cairo_t *cr,
 {
 }
 
-static gboolean
-gnm_so_polygon_read_xml_dom (SheetObject *so, char const *typename,
-			     XmlParseContext const *ctxt, xmlNodePtr node)
-{
-	GnmSOPolygon *sop = GNM_SO_POLYGON (so);
-	xmlNodePtr ptr;
-	double vals[2];
-
-	g_array_set_size (sop->points, 0);
-	for (ptr = node->xmlChildrenNode; ptr != NULL ; ptr = ptr->next)
-		if (!xmlIsBlankNode (ptr) && ptr->name &&
-		    attr_eq (ptr->name, "Point") &&
-		    go_xml_node_get_double	(ptr, "x", vals + 0) &&
-		    go_xml_node_get_double	(ptr, "y", vals + 1))
-			g_array_append_vals (sop->points, vals, 2);
-
-	return gnm_so_polygon_parent_class->
-		read_xml_dom (so, typename, ctxt, node);
-}
-
 static void
 gnm_so_polygon_write_xml_sax (SheetObject const *so, GsfXMLOut *output,
 			      GnmConventions const *convs)
@@ -233,19 +214,19 @@ gnm_so_polygon_copy (SheetObject *dst, SheetObject const *src)
 
 static void
 gnm_so_polygon_set_property (GObject *obj, guint param_id,
-			    GValue const *value, GParamSpec *pspec)
+			     GValue const *value, GParamSpec *pspec)
 {
 	GnmSOPolygon *sop = GNM_SO_POLYGON (obj);
 	GArray *points;
-	GOStyle *style;
 
 	switch (param_id) {
-	case SOP_PROP_STYLE:
-		style = sop->style;
-		sop->style = g_object_ref (g_value_get_object (value));
-		sop->style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
-		g_object_unref (style);
+	case SOP_PROP_STYLE: {
+		GOStyle *style = go_style_dup (g_value_get_object (value));
+		style->interesting_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
+		g_object_unref (sop->style);
+		sop->style = style;
 		break;
+	}
 	case SOP_PROP_POINTS:
 		points = g_value_get_pointer (value);
 		if (!points)
@@ -275,6 +256,9 @@ gnm_so_polygon_get_property (GObject *obj, guint param_id,
 	case SOP_PROP_POINTS:
 		g_value_set_pointer (value, sop->points);
 		break;
+	case SOP_PROP_DOCUMENT:
+		g_value_set_object (value, sheet_object_get_sheet (SHEET_OBJECT (obj))->workbook);
+		break;
 	default :
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
 		break;
@@ -305,7 +289,6 @@ gnm_so_polygon_class_init (GObjectClass *gobject_class)
 	gobject_class->finalize		= gnm_so_polygon_finalize;
 	gobject_class->set_property	= gnm_so_polygon_set_property;
 	gobject_class->get_property	= gnm_so_polygon_get_property;
-	so_class->read_xml_dom		= gnm_so_polygon_read_xml_dom;
 	so_class->write_xml_sax		= gnm_so_polygon_write_xml_sax;
 	so_class->copy			= gnm_so_polygon_copy;
 	so_class->rubber_band_directly	= FALSE;
@@ -323,6 +306,9 @@ gnm_so_polygon_class_init (GObjectClass *gobject_class)
         g_object_class_install_property (gobject_class, SOP_PROP_POINTS,
                  g_param_spec_pointer ("points", NULL, NULL,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE));
+	g_object_class_install_property (gobject_class, SOP_PROP_DOCUMENT,
+		g_param_spec_object ("document", NULL, NULL, GO_TYPE_DOC,
+			GSF_PARAM_STATIC | G_PARAM_READABLE));
 }
 
 static void
