@@ -42,7 +42,7 @@ struct _GOIOContextGtk {
 	guint files_total;
 	guint files_done;
 
-	gfloat progress;
+	double progress;
 	char *progress_msg;
 	gdouble latency;
 
@@ -91,19 +91,20 @@ cb_realize (GtkWindow *window, void *dummy)
 {
 	int sx, sy;
 	GdkWindowHints hints;
-	GtkAllocation *allocation;
+	GtkAllocation allocation;
 	GdkGeometry geom;
 	GdkRectangle rect;
 
 	/* In a Xinerama setup, we want the geometry of the actual display
 	 * unit, if available. See bug 59902.  */
-	gdk_screen_get_monitor_geometry (window->screen, 0, &rect);
+	gdk_screen_get_monitor_geometry (gtk_window_get_screen (window),
+					 0, &rect);
 	sx = rect.width;
 	sy = rect.height;
-	allocation = &GTK_WIDGET (window)->allocation;
+	gtk_widget_get_allocation (GTK_WIDGET (window), &allocation);
 
-	geom.base_width = allocation->width;
-	geom.base_height = allocation->height;
+	geom.base_width = allocation.width;
+	geom.base_height = allocation.height;
 	geom.min_width = geom.max_width = geom.base_width;
 	geom.min_height = geom.max_height = geom.base_height;
 
@@ -146,8 +147,9 @@ icg_show_gui (IOContextGtk *icg)
 		gtk_progress_bar_set_orientation (
 			icg->file_bar, GTK_PROGRESS_LEFT_TO_RIGHT);
 		gtk_progress_bar_set_text (icg->file_bar, "Files");
-		gtk_progress_bar_set_fraction (icg->file_bar,
-			(float) icg->files_done / (float) icg->files_total);
+		gtk_progress_bar_set_fraction
+			(icg->file_bar,
+			 icg->files_done / (double)icg->files_total);
 		gtk_box_pack_start (box, GTK_WIDGET (icg->file_bar),
 			FALSE, FALSE, 0);
 	}
@@ -188,8 +190,8 @@ static gboolean
 icg_user_is_impatient (IOContextGtk *icg)
 {
 	gdouble t = g_timer_elapsed (icg->timer, NULL);
-	gfloat progress = icg->progress;
-	gfloat forecast_delay = ICG_POPUP_DELAY / 3.0;
+	double progress = icg->progress;
+	double forecast_delay = ICG_POPUP_DELAY / 3.0;
 	gboolean ret = FALSE;
 
 	if (icg->progress == 0. && icg->files_done == 0)
@@ -204,7 +206,7 @@ icg_user_is_impatient (IOContextGtk *icg)
 			/* We're likely to be back shortly.  */
 			ret = (t > ICG_POPUP_DELAY * 0.8);
 		} else {
-			gfloat forecast = icg->latency;
+			double forecast = icg->latency;
 			forecast += (t - icg->latency) / progress;
 			ret = (forecast > ICG_POPUP_DELAY);
 		}
@@ -222,7 +224,7 @@ icg_get_password (GOCmdContext *cc, char const *filename)
 }
 
 static void
-icg_progress_set (GOCmdContext *cc, gfloat val)
+icg_progress_set (GOCmdContext *cc, double val)
 {
 	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
 
@@ -269,6 +271,19 @@ icg_error_error_info (GOCmdContext *cc, GOErrorInfo *error)
 	}
 }
 
+static void
+icg_error_error_info_list (GOCmdContext *cc, GSList *error)
+{
+	IOContextGtk *icg = IO_CONTEXT_GTK (cc);
+	if (icg->show_warnings && error != NULL && error->data != NULL) {
+		GtkWidget *dialog = gnumeric_go_error_info_dialog_new
+			(error->data);
+		gtk_widget_show_all (GTK_WIDGET (dialog));
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+	}
+}
+
 static void
 icg_set_num_files (GOIOContext *icg, guint files_total)
 {
@@ -288,8 +303,9 @@ icg_processing_file (GOIOContext *ioc, char const *file)
 		int maxlen = 40;
 
 		if (icg->files_total > 0)
-			gtk_progress_bar_set_fraction (icg->file_bar,
-				 (float) icg->files_done / (float) icg->files_total);
+			gtk_progress_bar_set_fraction
+				(icg->file_bar,
+				 icg->files_done / (double)icg->files_total);
 
 		gtk_progress_bar_set_fraction (icg->work_bar, 0.0);
 
@@ -367,6 +383,7 @@ icg_gnm_cmd_context_init (GOCmdContextClass *cc_class)
 	cc_class->progress_set         = icg_progress_set;
 	cc_class->progress_message_set = icg_progress_message_set;
 	cc_class->error.error_info     = icg_error_error_info;
+	cc_class->error_info_list      = icg_error_error_info_list;
 }
 
 static void
