@@ -16,6 +16,7 @@
 #include "gnumeric.h"
 #include "item-edit.h"
 #include "gnm-pane-impl.h"
+#include <dead-kittens.h>
 
 #include "item-cursor.h"
 #include "sheet-control-gui-priv.h"
@@ -116,7 +117,7 @@ item_edit_draw (GocItem const *item, cairo_t *cr)
 	/* avoid a weak/strong cursor to extent outside the item,
 	 a better fix would be to have enough room for cursors */
 	cairo_clip_preserve (cr);
-	if (!gnumeric_background_set (ie->style, cr, FALSE))
+	if (!gnumeric_background_set (ie->style, cr, FALSE, NULL))
 		cairo_set_source_rgba (cr, 1., 1., 0.878431373, 1.);
 	cairo_fill (cr);
 
@@ -262,7 +263,7 @@ item_edit_button_pressed (GocItem *item, int button, double x, double y)
 			target_index = strlen (text);
 			trailing = 0;
 		}
-		ie->sel_start = g_utf8_pointer_to_offset (text, text + target_index) + trailing; 
+		ie->sel_start = g_utf8_pointer_to_offset (text, text + target_index) + trailing;
 		gtk_editable_set_position (GTK_EDITABLE (ie->entry), ie->sel_start);
 
 		return TRUE;
@@ -425,6 +426,8 @@ item_edit_update_bounds (GocItem *item)
 
 		if ((dir == PANGO_DIRECTION_RTL && cdir == GOC_DIRECTION_RTL) ||
 		    (dir != PANGO_DIRECTION_RTL && cdir == GOC_DIRECTION_LTR)) {
+			GtkAllocation a;
+
 			while (col_size < width &&
 			       col <= pane->last_full.col &&
 			       col < gnm_sheet_get_last_col (sheet)) {
@@ -435,7 +438,8 @@ item_edit_update_bounds (GocItem *item)
 				if (ci->visible)
 					col_size += ci->size_pixels;
 			}
-			tmp = (pane->first_offset.x + canvas->allocation.width) / scale;
+			gtk_widget_get_allocation (GTK_WIDGET (canvas), &a);
+			tmp = (pane->first_offset.x + a.width) / scale;
 			item->x1 = item->x0 + (col_size + GNM_COL_MARGIN + GNM_COL_MARGIN + 1) / scale;
 
 			if (item->x1 >= tmp) {
