@@ -66,13 +66,6 @@ struct _ItemGrid {
 
 	ItemGridSelectionType selecting;
 
-	struct {
-		GdkGC      *fill;	/* Default background fill gc */
-		GdkGC      *cell;	/* Color used for the cell */
-		GdkGC      *empty;	/* GC used for drawing empty cells */
-		GdkGC      *bound;	/* the dark line at the edge */
-	} gc;
-
 	GnmRange bound;
 
 	/* information for the cursor motion handler */
@@ -204,14 +197,46 @@ item_grid_update_bounds (GocItem *item)
 	item->y1 = G_MAXINT64/2;
 }
 
+static void
+draw_function_marker (GnmCell const *cell, cairo_t *cr,
+		      double x, double y, double w, double h, int const dir)
+{
+	if (cell == NULL || !gnm_cell_has_expr (cell))
+		return;
+
+	cairo_save (cr);
+	cairo_new_path (cr);
+	cairo_rectangle (cr, x, y, w+1, h+1);
+	cairo_clip (cr);
+	cairo_new_path (cr);
+	if (dir > 0) {
+		cairo_move_to (cr, x, y);
+		cairo_line_to (cr, x + 10., y);
+		cairo_arc (cr, x, y, 10., 0., M_PI / 2.);
+	} else {
+		cairo_move_to (cr, x + w, y);
+		cairo_line_to (cr, x + w, y + 10.);
+		cairo_arc (cr, x + w, y, 10., M_PI/2., M_PI);
+	}
+	cairo_close_path (cr);
+	cairo_set_source_rgb(cr, 0.0, 1.0, 0.0);
+	cairo_fill_preserve (cr);
+	cairo_set_source_rgb(cr, 0.3, 0.3, 0.3);
+	cairo_set_line_width (cr, 0.5);
+	cairo_stroke (cr);
+	cairo_restore (cr);
+}
+
 static void
 item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 			     int start_x, int start_y,
 			     GnmRange const *view, GnmRange const *range,
-			     gboolean draw_selection)
+			     gboolean draw_selection, GtkStyle *theme)
 {
 	int l, r, t, b, last;
 	SheetView const *sv = scg_view (ig->scg);
+	WorkbookView *wbv = sv_wbv (sv);
+	gboolean show_function_cell_markers = wbv->show_function_cell_markers;
 	Sheet const *sheet  = sv->sheet;
 	GnmCell  const *cell   = sheet_cell_get (sheet, range->start.col, range->start.row);
 	int const dir = sheet->text_is_rtl ? -1 : 1;
@@ -253,7 +278,7 @@ item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 
 	/* Check for background THEN selection */
 	if (gnumeric_background_set (style, cr,
-		is_selected) || is_selected) {
+				     is_selected, theme) || is_selected) {
 		/* Remember X excludes the far pixels */
 		if (dir > 0)
 			cairo_rectangle (cr, l, t, r-l+1, b-t+1);
@@ -283,12 +308,19 @@ item_grid_draw_merged_range (cairo_t *cr, ItemGrid *ig,
 		if (ri->needs_respan)
 			row_calc_spans ((ColRowInfo *)ri, cell->pos.row, sheet);
 
-		if (dir > 0)
+		if (dir > 0) {
+			if (show_function_cell_markers)
+				draw_function_marker (cell, cr, l, t,
+						      r - l, b - t, dir);
 			cell_draw (cell, cr,
-				l, t, r - l, b - t, -1);
-		else
+				   l, t, r - l, b - t, -1);
+		} else {
+			if (show_function_cell_markers)
+				draw_function_marker (cell, cr, r, t,
+						      l - r, b - t, dir);
 			cell_draw (cell, cr,
-				r, t, l - r, b - t, -1);
+				   r, t, l - r, b - t, -1);
+		}
 	}
 	if (dir > 0)
 		gnm_style_border_draw_diag (style, cr, l, t, r, b);
@@ -300,7 +332,7 @@ static void
 item_grid_draw_background (cairo_t *cr, ItemGrid *ig,
 			   GnmStyle const *style,
 			   int col, int row, int x, int y, int w, int h,
-			   gboolean draw_selection)
+			   gboolean draw_selection, GtkStyle *theme)
 {
 	SheetView const *sv = scg_view (ig->scg);
 	gboolean const is_selected = draw_selection &&
@@ -308,7 +340,7 @@ item_grid_draw_background (cairo_t *cr, ItemGrid *ig,
 		sv_is_pos_selected (sv, col, row);
 	gboolean const has_back =
 		gnumeric_background_set (style, cr,
-					    is_selected);
+					 is_selected, theme);
 
 #if DEBUG_SELECTION_PAINT
 	if (is_selected) {
@@ -358,6 +390,10 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 	ItemGrid *ig = ITEM_GRID (item);
 	ColRowInfo const *ri = NULL, *next_ri = NULL;
 	int const dir = sheet->text_is_rtl ? -1 : 1;
+	SheetView const *sv = scg_view (ig->scg);
+	WorkbookView *wbv = sv_wbv (sv);
+	gboolean show_function_cell_markers = wbv->show_function_cell_markers;
+	GtkStyle *theme = gtk_widget_get_style (GTK_WIDGET (canvas));
 
 	/* To ensure that far and near borders get drawn we pretend to draw +-2
 	 * pixels around the target area which would include the surrounding
@@ -530,7 +566,9 @@ item_grid_draw_region (GocItem const *item, cairo_t *cr, double x_0, double y_0,
 
 					if (ci->visible)
 						item_grid_draw_merged_range (cr, ig,
-							start_x, y, &view, r, draw_selection);
+									     start_x, y, &view, r, 
+									     draw_selection,
+									     theme);
 				}
 			} else {
 				lag = &(ptr->next);
@@ -626,7 +664,8 @@ plain_draw : /* a quick hack to deal with 142267 */
 			item_grid_draw_background (cr, ig,
 				style, col, row, x, y,
 				ci->size_pixels, ri->size_pixels,
-				draw_selection);
+						   draw_selection, theme);
+
 
 			/* Is this part of a span?
 			 * 1) There are cells allocated in the row
@@ -642,11 +681,16 @@ plain_draw : /* a quick hack to deal with 142267 */
 				 * box.  Ignore blanks too.
 				 */
 				GnmCell const *cell = sheet_cell_get (sheet, col, row);
-				if (!gnm_cell_is_empty (cell) && cell != edit_cell)
+				if (!gnm_cell_is_empty (cell) && cell != edit_cell) {
+					if (show_function_cell_markers)
+						draw_function_marker (cell, cr, x, y,
+								      ci->size_pixels,
+								      ri->size_pixels,
+								      dir);
 					cell_draw (cell, cr,
 						   x, y, ci->size_pixels,
 						   ri->size_pixels, -1);
-
+				}
 			/* Only draw spaning cells after all the backgrounds
 			 * that we are going to draw have been drawn.  No need
 			 * to draw the edit cell, or blanks. */
@@ -668,10 +712,14 @@ plain_draw : /* a quick hack to deal with 142267 */
 				/* x, y are relative to this cell origin, but the cell
 				 * might be using columns to the left (if it is set to right
 				 * justify or center justify) compute the pixel difference */
-				if (start_span_col != cell->pos.col)
+				if (dir > 0 && start_span_col != cell->pos.col)
 					center_offset += scg_colrow_distance_get (
 						pane->simple.scg, TRUE,
 						start_span_col, cell->pos.col);
+				else if (dir < 0 && end_span_col != cell->pos.col)
+					center_offset += scg_colrow_distance_get (
+						pane->simple.scg, TRUE,
+						cell->pos.col, end_span_col);
 
 				if (start_span_col != col) {
 					offset = scg_colrow_distance_get (
@@ -691,9 +739,14 @@ plain_draw : /* a quick hack to deal with 142267 */
 						real_x -= offset;
 				}
 
+				if (show_function_cell_markers)
+					draw_function_marker (cell, cr, real_x, y,
+							      tmp_width,
+							      ri->size_pixels, dir);
 				cell_draw (cell, cr,
 					   real_x, y, tmp_width,
 					   ri->size_pixels, center_offset);
+
 			} else if (col != span->left)
 				sr.vertical [col] = NULL;
 
@@ -738,7 +791,7 @@ plain_draw : /* a quick hack to deal with 142267 */
 			ig_cairo_draw_bound (cr, x, start_y, x, y);
 		} else if (canvas->direction == GOC_DIRECTION_LTR && start_x < 1)
 			ig_cairo_draw_bound (cr, 1, start_y, 1, y);
-	    }
+	}
 
 	g_slist_free (merged_used);	   /* merges with bottom in view */
 	g_slist_free (merged_active_seen); /* merges with bottom the view */
@@ -1099,7 +1152,6 @@ item_grid_init (ItemGrid *ig)
 	item->y1 = 0;
 
 	ig->selecting = ITEM_GRID_NO_SELECTION;
-	ig->gc.fill = ig->gc.cell = ig->gc.empty = ig->gc.bound = NULL;
 	/* We need something at least as big as any sheet.  */
 	ig->bound.start.col = ig->bound.start.row = 0;
 	ig->bound.end.col = GNM_MAX_COLS - 1;
