@@ -87,7 +87,8 @@ struct _PrintInformation {
 	} error_display;
 
 	struct {
-		GnmPageBreaks *h, *v;
+		GnmPageBreaks *h,  /* between rows */
+			      *v;  /* between columns */
 	} page_breaks;
 	PrintHF		*header, *footer;
 
@@ -171,6 +172,8 @@ void        print_info_set_edge_to_below_header (PrintInformation *pi,
 						 double e_h);
 void        print_info_set_breaks (PrintInformation *pi, GnmPageBreaks *breaks);
 
+gboolean        print_info_has_manual_breaks (PrintInformation *pi);
+
 GnmPageBreaks	*gnm_page_breaks_new		(gboolean is_vert);
 GnmPageBreaks	*gnm_page_breaks_dup		(GnmPageBreaks const *src);
 void		 gnm_page_breaks_free		(GnmPageBreaks *breaks);
