@@ -1,10 +1,13 @@
-#ifndef GNUMERIC_RANGEFUNC_H
-#define GNUMERIC_RANGEFUNC_H
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+#ifndef _GNM_RANGEFUNC_H_
+# define _GNM_RANGEFUNC_H_
 
 #include "numbers.h"
-#include <goffice/utils/go-rangefunc.h>
+#include <goffice/goffice.h>
 
-#ifdef WITH_LONG_DOUBLE
+G_BEGIN_DECLS
+
+#ifdef GNM_WITH_LONG_DOUBLE
 #	define gnm_range_sum go_range_suml
 #	define gnm_range_sumsq go_range_sumsql
 #	define gnm_range_average go_range_averagel
@@ -12,10 +15,10 @@
 #	define gnm_range_max go_range_maxl
 #	define gnm_range_maxabs go_range_maxabsl
 #	define gnm_range_devsq go_range_devsql
-#	define gnm_range_fractile_inter go_range_fractile_interl
-#	define gnm_range_fractile_inter_nonconst go_range_fractile_inter_nonconstl
+#	define gnm_range_fractile_inter_sorted go_range_fractile_inter_sortedl
 #	define gnm_range_median_inter go_range_median_interl
-#	define gnm_range_median_inter_nonconst go_range_median_inter_nonconstl
+#	define gnm_range_median_inter_sorted go_range_median_inter_sortedl
+#       define gnm_range_increasing go_range_increasingl
 #else
 #	define gnm_range_sum go_range_sum
 #	define gnm_range_sumsq go_range_sumsq
@@ -24,10 +27,10 @@
 #	define gnm_range_max go_range_max
 #	define gnm_range_maxabs go_range_maxabs
 #	define gnm_range_devsq go_range_devsq
-#	define gnm_range_fractile_inter go_range_fractile_inter
-#	define gnm_range_fractile_inter_nonconst go_range_fractile_inter_nonconst
+#	define gnm_range_fractile_inter_sorted go_range_fractile_inter_sorted
 #	define gnm_range_median_inter go_range_median_inter
-#	define gnm_range_median_inter_nonconst go_range_median_inter_nonconst
+#	define gnm_range_median_inter_sorted go_range_median_inter_sorted
+#       define gnm_range_increasing go_range_increasing
 #endif
 
 int gnm_range_count		(gnm_float const *xs, int n, gnm_float *res);
@@ -60,7 +63,6 @@ int gnm_range_rsq_est	(gnm_float const *xs, const gnm_float *ys, int n, gnm_floa
 
 int gnm_range_mode	(gnm_float const *xs, int n, gnm_float *res);
 
-int gnm_range_min_k		 (gnm_float const *xs, int n, gnm_float *res, int k);
-int gnm_range_min_k_nonconst (gnm_float       *xs, int n, gnm_float *res, int k);
+G_END_DECLS
 
-#endif
+#endif /* _GNM_RANGEFUNC_H_ */
