@@ -63,7 +63,7 @@ static GObjectClass *parent_klass;
 static GQuark	sov_so_quark;
 static GQuark	sov_container_quark;
 
-void          
+void
 sheet_object_set_print_flag (SheetObject *so, gboolean *print)
 {
 	if (*print)
@@ -1039,17 +1039,15 @@ cb_sheet_objects_dup (GnmDependent *dep, SheetObject *so, gpointer user)
 void
 sheet_objects_dup (Sheet const *src, Sheet *dst, GnmRange *range)
 {
-	SheetObject *so;
-	SheetObject *new_so;
 	GSList *list;
 
 	g_return_if_fail (IS_SHEET (dst));
 	g_return_if_fail (dst->sheet_objects == NULL);
 
 	for (list = src->sheet_objects; list != NULL; list = list->next) {
-		so = (SheetObject *) list->data;
+		SheetObject *so = list->data;
 		if (range == NULL || range_overlap (range, &so->anchor.cell_bound)) {
-			new_so = sheet_object_dup (so);
+			SheetObject *new_so = sheet_object_dup (so);
 			if (new_so != NULL) {
 				sheet_object_set_sheet (new_so, dst);
 				sheet_object_foreach_dep (new_so, cb_sheet_objects_dup,
@@ -1486,19 +1484,19 @@ sheet_object_move_undo (GSList *objects, gboolean objects_created)
 		SheetObjectAnchor *tmp;
 
 		if (objects_created) {
-			undo = go_undo_combine 
-				(undo, 
-				 go_undo_unary_new 
-				 (g_object_ref (obj), 
+			undo = go_undo_combine
+				(undo,
+				 go_undo_unary_new
+				 (g_object_ref (obj),
 				  (GOUndoUnaryFunc) sheet_object_clear_sheet,
 				  (GFreeFunc) g_object_unref));
 		}
 
 		tmp = g_new (SheetObjectAnchor, 1);
 		*tmp = *sheet_object_get_anchor (obj);
-		undo = go_undo_combine 
-			(undo, go_undo_binary_new 
-			 (g_object_ref (obj), tmp, 
+		undo = go_undo_combine
+			(undo, go_undo_binary_new
+			 (g_object_ref (obj), tmp,
 			  (GOUndoBinaryFunc) sheet_object_set_anchor,
 			  (GFreeFunc) g_object_unref,
 			  (GFreeFunc) g_free));
@@ -1507,7 +1505,7 @@ sheet_object_move_undo (GSList *objects, gboolean objects_created)
 }
 
 GOUndo *
-sheet_object_move_do (GSList *objects, GSList *anchors, 
+sheet_object_move_do (GSList *objects, GSList *anchors,
 		      gboolean objects_created)
 {
 	GOUndo *undo = NULL;
@@ -1515,7 +1513,7 @@ sheet_object_move_do (GSList *objects, GSList *anchors,
 
 	g_return_val_if_fail (NULL != objects, NULL);
 	g_return_val_if_fail (NULL != anchors, NULL);
-	g_return_val_if_fail (g_slist_length (objects) 
+	g_return_val_if_fail (g_slist_length (objects)
 			      == g_slist_length (anchors), NULL);
 
 	for (; objs && anchs; objs = objs->next, anchs = anchs->next) {
@@ -1524,10 +1522,10 @@ sheet_object_move_do (GSList *objects, GSList *anchors,
 		SheetObjectAnchor *tmp;
 
 		if (objects_created) {
-			undo = go_undo_combine 
+			undo = go_undo_combine
 				(undo,
-				 go_undo_binary_new 
-				 (g_object_ref (obj), 
+				 go_undo_binary_new
+				 (g_object_ref (obj),
 				  sheet_object_get_sheet (obj),
 				  (GOUndoBinaryFunc) sheet_object_set_sheet,
 				  (GFreeFunc) g_object_unref,
@@ -1535,9 +1533,9 @@ sheet_object_move_do (GSList *objects, GSList *anchors,
 		}
 		tmp = g_new (SheetObjectAnchor, 1);
 		*tmp = *anch;
-		undo = go_undo_combine 
-			(go_undo_binary_new 
-			 (g_object_ref (obj), tmp, 
+		undo = go_undo_combine
+			(go_undo_binary_new
+			 (g_object_ref (obj), tmp,
 			  (GOUndoBinaryFunc) sheet_object_set_anchor,
 			  (GFreeFunc) g_object_unref,
 			  (GFreeFunc) g_free), undo);
