@@ -25,6 +25,7 @@
 #include <func.h>
 #include <dependent.h>
 #include <sheet.h>
+#include <sheet-style.h>
 #include <workbook.h>
 #include <sheet-view.h>
 #include <selection.h>
@@ -156,7 +157,8 @@ enum {
 	PROP_FLAGS,
 	PROP_SCG,
 	PROP_WBCG,
-	PROP_CONSTANT_FORMAT
+	PROP_CONSTANT_FORMAT,
+	PROP_EDITING_CANCELED
 };
 
 static guint signals[LAST_SIGNAL] = { 0 };
@@ -490,6 +492,8 @@ gee_set_property (GObject      *object,
 	case PROP_CONSTANT_FORMAT:
 		gee_set_format (gee, g_value_get_pointer (value));
 		break;
+	case PROP_EDITING_CANCELED:
+		gee->editing_canceled = g_value_get_boolean (value);
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
@@ -524,6 +528,8 @@ gee_get_property (GObject      *object,
 	case PROP_CONSTANT_FORMAT:
 		g_value_set_pointer (value, (gpointer)gee->constant_format);
 		break;
+	case PROP_EDITING_CANCELED:
+		g_value_set_boolean (value, gee->editing_canceled);
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 	}
@@ -872,6 +878,8 @@ gee_update_lexer_items (GnmExprEntry *gee)
 	GtkEditable *editable = GTK_EDITABLE (gee->entry);
 	char *str = gtk_editable_get_chars (editable, 0, -1);
 	Sheet *sheet = scg_sheet (gee->scg);
+	GOFormat const *format;
+	gboolean forced_text;
 
 	g_free (gee->lexer_items);
 	gee->lexer_items = NULL;
@@ -882,15 +890,19 @@ gee_update_lexer_items (GnmExprEntry *gee)
 	}
 
 	parse_pos_init_editpos (&gee->pp, scg_view (gee->scg));
+	format = gnm_style_get_format
+		(sheet_style_get (sheet, gee->pp.eval.col, gee->pp.eval.row));
+	forced_text = ((format != NULL) && go_format_is_text (format));
 
-	if (!gee->feedback_disabled) {
+	if (!gee->feedback_disabled && !forced_text) {
 		gee->texpr = gnm_expr_parse_str
 			((str[0] == '=') ? str+1 : str,
 			 &gee->pp, GNM_EXPR_PARSE_DEFAULT,
 			 sheet_get_conventions (sheet), NULL);
 	}
 
-	gee->tooltip.is_expr = (NULL != gnm_expr_char_start_p (str));
+	gee->tooltip.is_expr =  (!forced_text) &&
+		(NULL != gnm_expr_char_start_p (str));
 	if (!(gee->flags & GNM_EE_SINGLE_RANGE)) {
 		gee->lexer_items = gnm_expr_lex_all
 			(str, &gee->pp,
@@ -1520,6 +1532,12 @@ gee_class_init (GObjectClass *gobject_class)
 		g_cclosure_marshal_VOID__VOID,
 		G_TYPE_NONE, 0);
 
+
+	/* FIXME: remove the test when we require gtk+ 2.20 or later */
+	if (g_object_interface_find_property (g_type_interface_peek (gobject_class, gtk_cell_editable_get_type ()), "editing-canceled"))
+		g_object_class_override_property
+			(gobject_class, PROP_EDITING_CANCELED, "editing-canceled");
+
 	g_object_class_install_property
 		(gobject_class, PROP_UPDATE_POLICY,
 		 g_param_spec_enum ("update-policy",
