@@ -55,10 +55,11 @@ enum {
 	MS_FREEZE_VS_THAW   = 1 << 9,
 	MS_ADD_VS_REMOVE_FILTER = 1 << 10,
 	MS_SHOW_PRINTAREA   = 1 << 11,
-	MS_SELECT_OBJECT    = 1 << 12,
-	MS_FILTER_STATE_CHANGED = 1 << 13,
-	MS_COMMENT_LINKS_RANGE  = 1 << 14,
-	MS_COMMENT_LINKS    = 1 << 15
+	MS_PAGE_BREAKS      = 1 << 12,
+	MS_SELECT_OBJECT    = 1 << 13,
+	MS_FILTER_STATE_CHANGED = 1 << 14,
+	MS_COMMENT_LINKS_RANGE  = 1 << 15,
+	MS_COMMENT_LINKS    = 1 << 16
 };
 
 #define MS_ALL \
@@ -66,7 +67,7 @@ enum {
      MS_SHOWHIDE_DETAIL | MS_PASTE_SPECIAL |				    \
      MS_PRINT_SETUP | MS_SEARCH_REPLACE | MS_DEFINE_NAME | MS_CONSOLIDATE | \
      MS_FREEZE_VS_THAW | MS_ADD_VS_REMOVE_FILTER | MS_SHOW_PRINTAREA |      \
-     MS_SELECT_OBJECT | MS_FILTER_STATE_CHANGED)
+     MS_PAGE_BREAKS | MS_SELECT_OBJECT | MS_FILTER_STATE_CHANGED)
 #define MS_GURU_MENU_ITEMS \
     (MS_PRINT_SETUP | MS_SEARCH_REPLACE | MS_DEFINE_NAME | MS_CONSOLIDATE)
 
